# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from importlib import import_module
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.v2.billing import (
        bill_settings as bill_settings,
        collection_settings as collection_settings,
        intents as intents,
        license_fees as license_fees,
        pricing_plan_subscriptions as pricing_plan_subscriptions,
        pricing_plans as pricing_plans,
        rate_cards as rate_cards,
    )
    from stripe.params.v2.billing._bill_setting_create_params import (
        BillSettingCreateParams as BillSettingCreateParams,
        BillSettingCreateParamsCalculation as BillSettingCreateParamsCalculation,
        BillSettingCreateParamsCalculationTax as BillSettingCreateParamsCalculationTax,
        BillSettingCreateParamsInvoice as BillSettingCreateParamsInvoice,
        BillSettingCreateParamsInvoiceTimeUntilDue as BillSettingCreateParamsInvoiceTimeUntilDue,
    )
    from stripe.params.v2.billing._bill_setting_list_params import (
        BillSettingListParams as BillSettingListParams,
    )
    from stripe.params.v2.billing._bill_setting_retrieve_params import (
        BillSettingRetrieveParams as BillSettingRetrieveParams,
    )
    from stripe.params.v2.billing._bill_setting_update_params import (
        BillSettingUpdateParams as BillSettingUpdateParams,
        BillSettingUpdateParamsCalculation as BillSettingUpdateParamsCalculation,
        BillSettingUpdateParamsCalculationTax as BillSettingUpdateParamsCalculationTax,
        BillSettingUpdateParamsInvoice as BillSettingUpdateParamsInvoice,
        BillSettingUpdateParamsInvoiceTimeUntilDue as BillSettingUpdateParamsInvoiceTimeUntilDue,
    )
    from stripe.params.v2.billing._cadence_cancel_params import (
        CadenceCancelParams as CadenceCancelParams,
    )
    from stripe.params.v2.billing._cadence_create_params import (
        CadenceCreateParams as CadenceCreateParams,
        CadenceCreateParamsBillingCycle as CadenceCreateParamsBillingCycle,
        CadenceCreateParamsBillingCycleDay as CadenceCreateParamsBillingCycleDay,
        CadenceCreateParamsBillingCycleDayTime as CadenceCreateParamsBillingCycleDayTime,
        CadenceCreateParamsBillingCycleMonth as CadenceCreateParamsBillingCycleMonth,
        CadenceCreateParamsBillingCycleMonthTime as CadenceCreateParamsBillingCycleMonthTime,
        CadenceCreateParamsBillingCycleWeek as CadenceCreateParamsBillingCycleWeek,
        CadenceCreateParamsBillingCycleWeekTime as CadenceCreateParamsBillingCycleWeekTime,
        CadenceCreateParamsBillingCycleYear as CadenceCreateParamsBillingCycleYear,
        CadenceCreateParamsBillingCycleYearTime as CadenceCreateParamsBillingCycleYearTime,
        CadenceCreateParamsPayer as CadenceCreateParamsPayer,
        CadenceCreateParamsSettings as CadenceCreateParamsSettings,
        CadenceCreateParamsSettingsBill as CadenceCreateParamsSettingsBill,
        CadenceCreateParamsSettingsCollection as CadenceCreateParamsSettingsCollection,
    )
    from stripe.params.v2.billing._cadence_list_params import (
        CadenceListParams as CadenceListParams,
        CadenceListParamsPayer as CadenceListParamsPayer,
    )
    from stripe.params.v2.billing._cadence_retrieve_params import (
        CadenceRetrieveParams as CadenceRetrieveParams,
    )
    from stripe.params.v2.billing._cadence_update_params import (
        CadenceUpdateParams as CadenceUpdateParams,
        CadenceUpdateParamsPayer as CadenceUpdateParamsPayer,
        CadenceUpdateParamsSettings as CadenceUpdateParamsSettings,
        CadenceUpdateParamsSettingsBill as CadenceUpdateParamsSettingsBill,
        CadenceUpdateParamsSettingsCollection as CadenceUpdateParamsSettingsCollection,
    )
    from stripe.params.v2.billing._collection_setting_create_params import (
        CollectionSettingCreateParams as CollectionSettingCreateParams,
        CollectionSettingCreateParamsEmailDelivery as CollectionSettingCreateParamsEmailDelivery,
        CollectionSettingCreateParamsEmailDeliveryPaymentDue as CollectionSettingCreateParamsEmailDeliveryPaymentDue,
        CollectionSettingCreateParamsPaymentMethodOptions as CollectionSettingCreateParamsPaymentMethodOptions,
        CollectionSettingCreateParamsPaymentMethodOptionsAcssDebit as CollectionSettingCreateParamsPaymentMethodOptionsAcssDebit,
        CollectionSettingCreateParamsPaymentMethodOptionsAcssDebitMandateOptions as CollectionSettingCreateParamsPaymentMethodOptionsAcssDebitMandateOptions,
        CollectionSettingCreateParamsPaymentMethodOptionsBancontact as CollectionSettingCreateParamsPaymentMethodOptionsBancontact,
        CollectionSettingCreateParamsPaymentMethodOptionsCard as CollectionSettingCreateParamsPaymentMethodOptionsCard,
        CollectionSettingCreateParamsPaymentMethodOptionsCardMandateOptions as CollectionSettingCreateParamsPaymentMethodOptionsCardMandateOptions,
        CollectionSettingCreateParamsPaymentMethodOptionsCustomerBalance as CollectionSettingCreateParamsPaymentMethodOptionsCustomerBalance,
        CollectionSettingCreateParamsPaymentMethodOptionsCustomerBalanceBankTransfer as CollectionSettingCreateParamsPaymentMethodOptionsCustomerBalanceBankTransfer,
        CollectionSettingCreateParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer as CollectionSettingCreateParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer,
        CollectionSettingCreateParamsPaymentMethodOptionsUsBankAccount as CollectionSettingCreateParamsPaymentMethodOptionsUsBankAccount,
        CollectionSettingCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnections as CollectionSettingCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnections,
        CollectionSettingCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters as CollectionSettingCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters,
    )
    from stripe.params.v2.billing._collection_setting_list_params import (
        CollectionSettingListParams as CollectionSettingListParams,
    )
    from stripe.params.v2.billing._collection_setting_retrieve_params import (
        CollectionSettingRetrieveParams as CollectionSettingRetrieveParams,
    )
    from stripe.params.v2.billing._collection_setting_update_params import (
        CollectionSettingUpdateParams as CollectionSettingUpdateParams,
        CollectionSettingUpdateParamsEmailDelivery as CollectionSettingUpdateParamsEmailDelivery,
        CollectionSettingUpdateParamsEmailDeliveryPaymentDue as CollectionSettingUpdateParamsEmailDeliveryPaymentDue,
        CollectionSettingUpdateParamsPaymentMethodOptions as CollectionSettingUpdateParamsPaymentMethodOptions,
        CollectionSettingUpdateParamsPaymentMethodOptionsAcssDebit as CollectionSettingUpdateParamsPaymentMethodOptionsAcssDebit,
        CollectionSettingUpdateParamsPaymentMethodOptionsAcssDebitMandateOptions as CollectionSettingUpdateParamsPaymentMethodOptionsAcssDebitMandateOptions,
        CollectionSettingUpdateParamsPaymentMethodOptionsBancontact as CollectionSettingUpdateParamsPaymentMethodOptionsBancontact,
        CollectionSettingUpdateParamsPaymentMethodOptionsCard as CollectionSettingUpdateParamsPaymentMethodOptionsCard,
        CollectionSettingUpdateParamsPaymentMethodOptionsCardMandateOptions as CollectionSettingUpdateParamsPaymentMethodOptionsCardMandateOptions,
        CollectionSettingUpdateParamsPaymentMethodOptionsCustomerBalance as CollectionSettingUpdateParamsPaymentMethodOptionsCustomerBalance,
        CollectionSettingUpdateParamsPaymentMethodOptionsCustomerBalanceBankTransfer as CollectionSettingUpdateParamsPaymentMethodOptionsCustomerBalanceBankTransfer,
        CollectionSettingUpdateParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer as CollectionSettingUpdateParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer,
        CollectionSettingUpdateParamsPaymentMethodOptionsUsBankAccount as CollectionSettingUpdateParamsPaymentMethodOptionsUsBankAccount,
        CollectionSettingUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnections as CollectionSettingUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnections,
        CollectionSettingUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters as CollectionSettingUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters,
    )
    from stripe.params.v2.billing._custom_pricing_unit_create_params import (
        CustomPricingUnitCreateParams as CustomPricingUnitCreateParams,
    )
    from stripe.params.v2.billing._custom_pricing_unit_list_params import (
        CustomPricingUnitListParams as CustomPricingUnitListParams,
    )
    from stripe.params.v2.billing._custom_pricing_unit_retrieve_params import (
        CustomPricingUnitRetrieveParams as CustomPricingUnitRetrieveParams,
    )
    from stripe.params.v2.billing._custom_pricing_unit_update_params import (
        CustomPricingUnitUpdateParams as CustomPricingUnitUpdateParams,
    )
    from stripe.params.v2.billing._intent_cancel_params import (
        IntentCancelParams as IntentCancelParams,
    )
    from stripe.params.v2.billing._intent_commit_params import (
        IntentCommitParams as IntentCommitParams,
    )
    from stripe.params.v2.billing._intent_create_params import (
        IntentCreateParams as IntentCreateParams,
        IntentCreateParamsAction as IntentCreateParamsAction,
        IntentCreateParamsActionApply as IntentCreateParamsActionApply,
        IntentCreateParamsActionApplyInvoiceDiscountRule as IntentCreateParamsActionApplyInvoiceDiscountRule,
        IntentCreateParamsActionApplyInvoiceDiscountRulePercentOff as IntentCreateParamsActionApplyInvoiceDiscountRulePercentOff,
        IntentCreateParamsActionApplyInvoiceDiscountRulePercentOffMaximumApplications as IntentCreateParamsActionApplyInvoiceDiscountRulePercentOffMaximumApplications,
        IntentCreateParamsActionDeactivate as IntentCreateParamsActionDeactivate,
        IntentCreateParamsActionDeactivateBillingDetails as IntentCreateParamsActionDeactivateBillingDetails,
        IntentCreateParamsActionDeactivateEffectiveAt as IntentCreateParamsActionDeactivateEffectiveAt,
        IntentCreateParamsActionDeactivatePricingPlanSubscriptionDetails as IntentCreateParamsActionDeactivatePricingPlanSubscriptionDetails,
        IntentCreateParamsActionModify as IntentCreateParamsActionModify,
        IntentCreateParamsActionModifyBillingDetails as IntentCreateParamsActionModifyBillingDetails,
        IntentCreateParamsActionModifyEffectiveAt as IntentCreateParamsActionModifyEffectiveAt,
        IntentCreateParamsActionModifyPricingPlanSubscriptionDetails as IntentCreateParamsActionModifyPricingPlanSubscriptionDetails,
        IntentCreateParamsActionModifyPricingPlanSubscriptionDetailsComponentConfiguration as IntentCreateParamsActionModifyPricingPlanSubscriptionDetailsComponentConfiguration,
        IntentCreateParamsActionRemove as IntentCreateParamsActionRemove,
        IntentCreateParamsActionSubscribe as IntentCreateParamsActionSubscribe,
        IntentCreateParamsActionSubscribeBillingDetails as IntentCreateParamsActionSubscribeBillingDetails,
        IntentCreateParamsActionSubscribeEffectiveAt as IntentCreateParamsActionSubscribeEffectiveAt,
        IntentCreateParamsActionSubscribePricingPlanSubscriptionDetails as IntentCreateParamsActionSubscribePricingPlanSubscriptionDetails,
        IntentCreateParamsActionSubscribePricingPlanSubscriptionDetailsComponentConfiguration as IntentCreateParamsActionSubscribePricingPlanSubscriptionDetailsComponentConfiguration,
        IntentCreateParamsActionSubscribeV1SubscriptionDetails as IntentCreateParamsActionSubscribeV1SubscriptionDetails,
        IntentCreateParamsActionSubscribeV1SubscriptionDetailsItem as IntentCreateParamsActionSubscribeV1SubscriptionDetailsItem,
    )
    from stripe.params.v2.billing._intent_list_params import (
        IntentListParams as IntentListParams,
    )
    from stripe.params.v2.billing._intent_release_reservation_params import (
        IntentReleaseReservationParams as IntentReleaseReservationParams,
    )
    from stripe.params.v2.billing._intent_reserve_params import (
        IntentReserveParams as IntentReserveParams,
    )
    from stripe.params.v2.billing._intent_retrieve_params import (
        IntentRetrieveParams as IntentRetrieveParams,
    )
    from stripe.params.v2.billing._license_fee_create_params import (
        LicenseFeeCreateParams as LicenseFeeCreateParams,
        LicenseFeeCreateParamsTier as LicenseFeeCreateParamsTier,
        LicenseFeeCreateParamsTransformQuantity as LicenseFeeCreateParamsTransformQuantity,
    )
    from stripe.params.v2.billing._license_fee_list_params import (
        LicenseFeeListParams as LicenseFeeListParams,
    )
    from stripe.params.v2.billing._license_fee_retrieve_params import (
        LicenseFeeRetrieveParams as LicenseFeeRetrieveParams,
    )
    from stripe.params.v2.billing._license_fee_subscription_retrieve_params import (
        LicenseFeeSubscriptionRetrieveParams as LicenseFeeSubscriptionRetrieveParams,
    )
    from stripe.params.v2.billing._license_fee_update_params import (
        LicenseFeeUpdateParams as LicenseFeeUpdateParams,
        LicenseFeeUpdateParamsTier as LicenseFeeUpdateParamsTier,
        LicenseFeeUpdateParamsTransformQuantity as LicenseFeeUpdateParamsTransformQuantity,
    )
    from stripe.params.v2.billing._licensed_item_create_params import (
        LicensedItemCreateParams as LicensedItemCreateParams,
        LicensedItemCreateParamsTaxDetails as LicensedItemCreateParamsTaxDetails,
    )
    from stripe.params.v2.billing._licensed_item_list_params import (
        LicensedItemListParams as LicensedItemListParams,
    )
    from stripe.params.v2.billing._licensed_item_retrieve_params import (
        LicensedItemRetrieveParams as LicensedItemRetrieveParams,
    )
    from stripe.params.v2.billing._licensed_item_update_params import (
        LicensedItemUpdateParams as LicensedItemUpdateParams,
        LicensedItemUpdateParamsTaxDetails as LicensedItemUpdateParamsTaxDetails,
    )
    from stripe.params.v2.billing._meter_event_adjustment_create_params import (
        MeterEventAdjustmentCreateParams as MeterEventAdjustmentCreateParams,
        MeterEventAdjustmentCreateParamsCancel as MeterEventAdjustmentCreateParamsCancel,
    )
    from stripe.params.v2.billing._meter_event_create_params import (
        MeterEventCreateParams as MeterEventCreateParams,
    )
    from stripe.params.v2.billing._meter_event_session_create_params import (
        MeterEventSessionCreateParams as MeterEventSessionCreateParams,
    )
    from stripe.params.v2.billing._meter_event_stream_create_params import (
        MeterEventStreamCreateParams as MeterEventStreamCreateParams,
        MeterEventStreamCreateParamsEvent as MeterEventStreamCreateParamsEvent,
    )
    from stripe.params.v2.billing._metered_item_create_params import (
        MeteredItemCreateParams as MeteredItemCreateParams,
        MeteredItemCreateParamsMeterSegmentCondition as MeteredItemCreateParamsMeterSegmentCondition,
        MeteredItemCreateParamsTaxDetails as MeteredItemCreateParamsTaxDetails,
    )
    from stripe.params.v2.billing._metered_item_list_params import (
        MeteredItemListParams as MeteredItemListParams,
    )
    from stripe.params.v2.billing._metered_item_retrieve_params import (
        MeteredItemRetrieveParams as MeteredItemRetrieveParams,
    )
    from stripe.params.v2.billing._metered_item_update_params import (
        MeteredItemUpdateParams as MeteredItemUpdateParams,
        MeteredItemUpdateParamsTaxDetails as MeteredItemUpdateParamsTaxDetails,
    )
    from stripe.params.v2.billing._pricing_plan_create_params import (
        PricingPlanCreateParams as PricingPlanCreateParams,
    )
    from stripe.params.v2.billing._pricing_plan_list_params import (
        PricingPlanListParams as PricingPlanListParams,
    )
    from stripe.params.v2.billing._pricing_plan_retrieve_params import (
        PricingPlanRetrieveParams as PricingPlanRetrieveParams,
    )
    from stripe.params.v2.billing._pricing_plan_subscription_list_params import (
        PricingPlanSubscriptionListParams as PricingPlanSubscriptionListParams,
        PricingPlanSubscriptionListParamsPayer as PricingPlanSubscriptionListParamsPayer,
    )
    from stripe.params.v2.billing._pricing_plan_subscription_retrieve_params import (
        PricingPlanSubscriptionRetrieveParams as PricingPlanSubscriptionRetrieveParams,
    )
    from stripe.params.v2.billing._pricing_plan_subscription_update_params import (
        PricingPlanSubscriptionUpdateParams as PricingPlanSubscriptionUpdateParams,
    )
    from stripe.params.v2.billing._pricing_plan_update_params import (
        PricingPlanUpdateParams as PricingPlanUpdateParams,
    )
    from stripe.params.v2.billing._profile_create_params import (
        ProfileCreateParams as ProfileCreateParams,
    )
    from stripe.params.v2.billing._profile_list_params import (
        ProfileListParams as ProfileListParams,
    )
    from stripe.params.v2.billing._profile_retrieve_params import (
        ProfileRetrieveParams as ProfileRetrieveParams,
    )
    from stripe.params.v2.billing._profile_update_params import (
        ProfileUpdateParams as ProfileUpdateParams,
    )
    from stripe.params.v2.billing._rate_card_create_params import (
        RateCardCreateParams as RateCardCreateParams,
    )
    from stripe.params.v2.billing._rate_card_list_params import (
        RateCardListParams as RateCardListParams,
    )
    from stripe.params.v2.billing._rate_card_retrieve_params import (
        RateCardRetrieveParams as RateCardRetrieveParams,
    )
    from stripe.params.v2.billing._rate_card_subscription_cancel_params import (
        RateCardSubscriptionCancelParams as RateCardSubscriptionCancelParams,
    )
    from stripe.params.v2.billing._rate_card_subscription_create_params import (
        RateCardSubscriptionCreateParams as RateCardSubscriptionCreateParams,
    )
    from stripe.params.v2.billing._rate_card_subscription_list_params import (
        RateCardSubscriptionListParams as RateCardSubscriptionListParams,
        RateCardSubscriptionListParamsPayer as RateCardSubscriptionListParamsPayer,
    )
    from stripe.params.v2.billing._rate_card_subscription_retrieve_params import (
        RateCardSubscriptionRetrieveParams as RateCardSubscriptionRetrieveParams,
    )
    from stripe.params.v2.billing._rate_card_subscription_update_params import (
        RateCardSubscriptionUpdateParams as RateCardSubscriptionUpdateParams,
    )
    from stripe.params.v2.billing._rate_card_update_params import (
        RateCardUpdateParams as RateCardUpdateParams,
    )
    from stripe.params.v2.billing._service_action_create_params import (
        ServiceActionCreateParams as ServiceActionCreateParams,
        ServiceActionCreateParamsCreditGrant as ServiceActionCreateParamsCreditGrant,
        ServiceActionCreateParamsCreditGrantAmount as ServiceActionCreateParamsCreditGrantAmount,
        ServiceActionCreateParamsCreditGrantAmountCustomPricingUnit as ServiceActionCreateParamsCreditGrantAmountCustomPricingUnit,
        ServiceActionCreateParamsCreditGrantApplicabilityConfig as ServiceActionCreateParamsCreditGrantApplicabilityConfig,
        ServiceActionCreateParamsCreditGrantApplicabilityConfigScope as ServiceActionCreateParamsCreditGrantApplicabilityConfigScope,
        ServiceActionCreateParamsCreditGrantExpiryConfig as ServiceActionCreateParamsCreditGrantExpiryConfig,
        ServiceActionCreateParamsCreditGrantPerTenant as ServiceActionCreateParamsCreditGrantPerTenant,
        ServiceActionCreateParamsCreditGrantPerTenantAmount as ServiceActionCreateParamsCreditGrantPerTenantAmount,
        ServiceActionCreateParamsCreditGrantPerTenantAmountCustomPricingUnit as ServiceActionCreateParamsCreditGrantPerTenantAmountCustomPricingUnit,
        ServiceActionCreateParamsCreditGrantPerTenantApplicabilityConfig as ServiceActionCreateParamsCreditGrantPerTenantApplicabilityConfig,
        ServiceActionCreateParamsCreditGrantPerTenantApplicabilityConfigScope as ServiceActionCreateParamsCreditGrantPerTenantApplicabilityConfigScope,
        ServiceActionCreateParamsCreditGrantPerTenantExpiryConfig as ServiceActionCreateParamsCreditGrantPerTenantExpiryConfig,
        ServiceActionCreateParamsCreditGrantPerTenantGrantCondition as ServiceActionCreateParamsCreditGrantPerTenantGrantCondition,
        ServiceActionCreateParamsCreditGrantPerTenantGrantConditionMeterEventFirstPerPeriod as ServiceActionCreateParamsCreditGrantPerTenantGrantConditionMeterEventFirstPerPeriod,
        ServiceActionCreateParamsCreditGrantPerTenantGrantConditionMeterEventFirstPerPeriodMeterSegmentCondition as ServiceActionCreateParamsCreditGrantPerTenantGrantConditionMeterEventFirstPerPeriodMeterSegmentCondition,
        ServiceActionCreateParamsCreditGrantPerTenantGrantConditionMeterEventFirstPerPeriodMeterSegmentConditionDimension as ServiceActionCreateParamsCreditGrantPerTenantGrantConditionMeterEventFirstPerPeriodMeterSegmentConditionDimension,
    )
    from stripe.params.v2.billing._service_action_retrieve_params import (
        ServiceActionRetrieveParams as ServiceActionRetrieveParams,
    )
    from stripe.params.v2.billing._service_action_update_params import (
        ServiceActionUpdateParams as ServiceActionUpdateParams,
        ServiceActionUpdateParamsCreditGrant as ServiceActionUpdateParamsCreditGrant,
        ServiceActionUpdateParamsCreditGrantPerTenant as ServiceActionUpdateParamsCreditGrantPerTenant,
    )

# name -> (import_target, is_submodule)
_import_map = {
    "bill_settings": ("stripe.params.v2.billing.bill_settings", True),
    "collection_settings": (
        "stripe.params.v2.billing.collection_settings",
        True,
    ),
    "intents": ("stripe.params.v2.billing.intents", True),
    "license_fees": ("stripe.params.v2.billing.license_fees", True),
    "pricing_plan_subscriptions": (
        "stripe.params.v2.billing.pricing_plan_subscriptions",
        True,
    ),
    "pricing_plans": ("stripe.params.v2.billing.pricing_plans", True),
    "rate_cards": ("stripe.params.v2.billing.rate_cards", True),
    "BillSettingCreateParams": (
        "stripe.params.v2.billing._bill_setting_create_params",
        False,
    ),
    "BillSettingCreateParamsCalculation": (
        "stripe.params.v2.billing._bill_setting_create_params",
        False,
    ),
    "BillSettingCreateParamsCalculationTax": (
        "stripe.params.v2.billing._bill_setting_create_params",
        False,
    ),
    "BillSettingCreateParamsInvoice": (
        "stripe.params.v2.billing._bill_setting_create_params",
        False,
    ),
    "BillSettingCreateParamsInvoiceTimeUntilDue": (
        "stripe.params.v2.billing._bill_setting_create_params",
        False,
    ),
    "BillSettingListParams": (
        "stripe.params.v2.billing._bill_setting_list_params",
        False,
    ),
    "BillSettingRetrieveParams": (
        "stripe.params.v2.billing._bill_setting_retrieve_params",
        False,
    ),
    "BillSettingUpdateParams": (
        "stripe.params.v2.billing._bill_setting_update_params",
        False,
    ),
    "BillSettingUpdateParamsCalculation": (
        "stripe.params.v2.billing._bill_setting_update_params",
        False,
    ),
    "BillSettingUpdateParamsCalculationTax": (
        "stripe.params.v2.billing._bill_setting_update_params",
        False,
    ),
    "BillSettingUpdateParamsInvoice": (
        "stripe.params.v2.billing._bill_setting_update_params",
        False,
    ),
    "BillSettingUpdateParamsInvoiceTimeUntilDue": (
        "stripe.params.v2.billing._bill_setting_update_params",
        False,
    ),
    "CadenceCancelParams": (
        "stripe.params.v2.billing._cadence_cancel_params",
        False,
    ),
    "CadenceCreateParams": (
        "stripe.params.v2.billing._cadence_create_params",
        False,
    ),
    "CadenceCreateParamsBillingCycle": (
        "stripe.params.v2.billing._cadence_create_params",
        False,
    ),
    "CadenceCreateParamsBillingCycleDay": (
        "stripe.params.v2.billing._cadence_create_params",
        False,
    ),
    "CadenceCreateParamsBillingCycleDayTime": (
        "stripe.params.v2.billing._cadence_create_params",
        False,
    ),
    "CadenceCreateParamsBillingCycleMonth": (
        "stripe.params.v2.billing._cadence_create_params",
        False,
    ),
    "CadenceCreateParamsBillingCycleMonthTime": (
        "stripe.params.v2.billing._cadence_create_params",
        False,
    ),
    "CadenceCreateParamsBillingCycleWeek": (
        "stripe.params.v2.billing._cadence_create_params",
        False,
    ),
    "CadenceCreateParamsBillingCycleWeekTime": (
        "stripe.params.v2.billing._cadence_create_params",
        False,
    ),
    "CadenceCreateParamsBillingCycleYear": (
        "stripe.params.v2.billing._cadence_create_params",
        False,
    ),
    "CadenceCreateParamsBillingCycleYearTime": (
        "stripe.params.v2.billing._cadence_create_params",
        False,
    ),
    "CadenceCreateParamsPayer": (
        "stripe.params.v2.billing._cadence_create_params",
        False,
    ),
    "CadenceCreateParamsSettings": (
        "stripe.params.v2.billing._cadence_create_params",
        False,
    ),
    "CadenceCreateParamsSettingsBill": (
        "stripe.params.v2.billing._cadence_create_params",
        False,
    ),
    "CadenceCreateParamsSettingsCollection": (
        "stripe.params.v2.billing._cadence_create_params",
        False,
    ),
    "CadenceListParams": (
        "stripe.params.v2.billing._cadence_list_params",
        False,
    ),
    "CadenceListParamsPayer": (
        "stripe.params.v2.billing._cadence_list_params",
        False,
    ),
    "CadenceRetrieveParams": (
        "stripe.params.v2.billing._cadence_retrieve_params",
        False,
    ),
    "CadenceUpdateParams": (
        "stripe.params.v2.billing._cadence_update_params",
        False,
    ),
    "CadenceUpdateParamsPayer": (
        "stripe.params.v2.billing._cadence_update_params",
        False,
    ),
    "CadenceUpdateParamsSettings": (
        "stripe.params.v2.billing._cadence_update_params",
        False,
    ),
    "CadenceUpdateParamsSettingsBill": (
        "stripe.params.v2.billing._cadence_update_params",
        False,
    ),
    "CadenceUpdateParamsSettingsCollection": (
        "stripe.params.v2.billing._cadence_update_params",
        False,
    ),
    "CollectionSettingCreateParams": (
        "stripe.params.v2.billing._collection_setting_create_params",
        False,
    ),
    "CollectionSettingCreateParamsEmailDelivery": (
        "stripe.params.v2.billing._collection_setting_create_params",
        False,
    ),
    "CollectionSettingCreateParamsEmailDeliveryPaymentDue": (
        "stripe.params.v2.billing._collection_setting_create_params",
        False,
    ),
    "CollectionSettingCreateParamsPaymentMethodOptions": (
        "stripe.params.v2.billing._collection_setting_create_params",
        False,
    ),
    "CollectionSettingCreateParamsPaymentMethodOptionsAcssDebit": (
        "stripe.params.v2.billing._collection_setting_create_params",
        False,
    ),
    "CollectionSettingCreateParamsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params.v2.billing._collection_setting_create_params",
        False,
    ),
    "CollectionSettingCreateParamsPaymentMethodOptionsBancontact": (
        "stripe.params.v2.billing._collection_setting_create_params",
        False,
    ),
    "CollectionSettingCreateParamsPaymentMethodOptionsCard": (
        "stripe.params.v2.billing._collection_setting_create_params",
        False,
    ),
    "CollectionSettingCreateParamsPaymentMethodOptionsCardMandateOptions": (
        "stripe.params.v2.billing._collection_setting_create_params",
        False,
    ),
    "CollectionSettingCreateParamsPaymentMethodOptionsCustomerBalance": (
        "stripe.params.v2.billing._collection_setting_create_params",
        False,
    ),
    "CollectionSettingCreateParamsPaymentMethodOptionsCustomerBalanceBankTransfer": (
        "stripe.params.v2.billing._collection_setting_create_params",
        False,
    ),
    "CollectionSettingCreateParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer": (
        "stripe.params.v2.billing._collection_setting_create_params",
        False,
    ),
    "CollectionSettingCreateParamsPaymentMethodOptionsUsBankAccount": (
        "stripe.params.v2.billing._collection_setting_create_params",
        False,
    ),
    "CollectionSettingCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnections": (
        "stripe.params.v2.billing._collection_setting_create_params",
        False,
    ),
    "CollectionSettingCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters": (
        "stripe.params.v2.billing._collection_setting_create_params",
        False,
    ),
    "CollectionSettingListParams": (
        "stripe.params.v2.billing._collection_setting_list_params",
        False,
    ),
    "CollectionSettingRetrieveParams": (
        "stripe.params.v2.billing._collection_setting_retrieve_params",
        False,
    ),
    "CollectionSettingUpdateParams": (
        "stripe.params.v2.billing._collection_setting_update_params",
        False,
    ),
    "CollectionSettingUpdateParamsEmailDelivery": (
        "stripe.params.v2.billing._collection_setting_update_params",
        False,
    ),
    "CollectionSettingUpdateParamsEmailDeliveryPaymentDue": (
        "stripe.params.v2.billing._collection_setting_update_params",
        False,
    ),
    "CollectionSettingUpdateParamsPaymentMethodOptions": (
        "stripe.params.v2.billing._collection_setting_update_params",
        False,
    ),
    "CollectionSettingUpdateParamsPaymentMethodOptionsAcssDebit": (
        "stripe.params.v2.billing._collection_setting_update_params",
        False,
    ),
    "CollectionSettingUpdateParamsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params.v2.billing._collection_setting_update_params",
        False,
    ),
    "CollectionSettingUpdateParamsPaymentMethodOptionsBancontact": (
        "stripe.params.v2.billing._collection_setting_update_params",
        False,
    ),
    "CollectionSettingUpdateParamsPaymentMethodOptionsCard": (
        "stripe.params.v2.billing._collection_setting_update_params",
        False,
    ),
    "CollectionSettingUpdateParamsPaymentMethodOptionsCardMandateOptions": (
        "stripe.params.v2.billing._collection_setting_update_params",
        False,
    ),
    "CollectionSettingUpdateParamsPaymentMethodOptionsCustomerBalance": (
        "stripe.params.v2.billing._collection_setting_update_params",
        False,
    ),
    "CollectionSettingUpdateParamsPaymentMethodOptionsCustomerBalanceBankTransfer": (
        "stripe.params.v2.billing._collection_setting_update_params",
        False,
    ),
    "CollectionSettingUpdateParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer": (
        "stripe.params.v2.billing._collection_setting_update_params",
        False,
    ),
    "CollectionSettingUpdateParamsPaymentMethodOptionsUsBankAccount": (
        "stripe.params.v2.billing._collection_setting_update_params",
        False,
    ),
    "CollectionSettingUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnections": (
        "stripe.params.v2.billing._collection_setting_update_params",
        False,
    ),
    "CollectionSettingUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters": (
        "stripe.params.v2.billing._collection_setting_update_params",
        False,
    ),
    "CustomPricingUnitCreateParams": (
        "stripe.params.v2.billing._custom_pricing_unit_create_params",
        False,
    ),
    "CustomPricingUnitListParams": (
        "stripe.params.v2.billing._custom_pricing_unit_list_params",
        False,
    ),
    "CustomPricingUnitRetrieveParams": (
        "stripe.params.v2.billing._custom_pricing_unit_retrieve_params",
        False,
    ),
    "CustomPricingUnitUpdateParams": (
        "stripe.params.v2.billing._custom_pricing_unit_update_params",
        False,
    ),
    "IntentCancelParams": (
        "stripe.params.v2.billing._intent_cancel_params",
        False,
    ),
    "IntentCommitParams": (
        "stripe.params.v2.billing._intent_commit_params",
        False,
    ),
    "IntentCreateParams": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsAction": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionApply": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionApplyInvoiceDiscountRule": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionApplyInvoiceDiscountRulePercentOff": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionApplyInvoiceDiscountRulePercentOffMaximumApplications": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionDeactivate": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionDeactivateBillingDetails": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionDeactivateEffectiveAt": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionDeactivatePricingPlanSubscriptionDetails": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionModify": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionModifyBillingDetails": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionModifyEffectiveAt": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionModifyPricingPlanSubscriptionDetails": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionModifyPricingPlanSubscriptionDetailsComponentConfiguration": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionRemove": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionSubscribe": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionSubscribeBillingDetails": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionSubscribeEffectiveAt": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionSubscribePricingPlanSubscriptionDetails": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionSubscribePricingPlanSubscriptionDetailsComponentConfiguration": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionSubscribeV1SubscriptionDetails": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentCreateParamsActionSubscribeV1SubscriptionDetailsItem": (
        "stripe.params.v2.billing._intent_create_params",
        False,
    ),
    "IntentListParams": (
        "stripe.params.v2.billing._intent_list_params",
        False,
    ),
    "IntentReleaseReservationParams": (
        "stripe.params.v2.billing._intent_release_reservation_params",
        False,
    ),
    "IntentReserveParams": (
        "stripe.params.v2.billing._intent_reserve_params",
        False,
    ),
    "IntentRetrieveParams": (
        "stripe.params.v2.billing._intent_retrieve_params",
        False,
    ),
    "LicenseFeeCreateParams": (
        "stripe.params.v2.billing._license_fee_create_params",
        False,
    ),
    "LicenseFeeCreateParamsTier": (
        "stripe.params.v2.billing._license_fee_create_params",
        False,
    ),
    "LicenseFeeCreateParamsTransformQuantity": (
        "stripe.params.v2.billing._license_fee_create_params",
        False,
    ),
    "LicenseFeeListParams": (
        "stripe.params.v2.billing._license_fee_list_params",
        False,
    ),
    "LicenseFeeRetrieveParams": (
        "stripe.params.v2.billing._license_fee_retrieve_params",
        False,
    ),
    "LicenseFeeSubscriptionRetrieveParams": (
        "stripe.params.v2.billing._license_fee_subscription_retrieve_params",
        False,
    ),
    "LicenseFeeUpdateParams": (
        "stripe.params.v2.billing._license_fee_update_params",
        False,
    ),
    "LicenseFeeUpdateParamsTier": (
        "stripe.params.v2.billing._license_fee_update_params",
        False,
    ),
    "LicenseFeeUpdateParamsTransformQuantity": (
        "stripe.params.v2.billing._license_fee_update_params",
        False,
    ),
    "LicensedItemCreateParams": (
        "stripe.params.v2.billing._licensed_item_create_params",
        False,
    ),
    "LicensedItemCreateParamsTaxDetails": (
        "stripe.params.v2.billing._licensed_item_create_params",
        False,
    ),
    "LicensedItemListParams": (
        "stripe.params.v2.billing._licensed_item_list_params",
        False,
    ),
    "LicensedItemRetrieveParams": (
        "stripe.params.v2.billing._licensed_item_retrieve_params",
        False,
    ),
    "LicensedItemUpdateParams": (
        "stripe.params.v2.billing._licensed_item_update_params",
        False,
    ),
    "LicensedItemUpdateParamsTaxDetails": (
        "stripe.params.v2.billing._licensed_item_update_params",
        False,
    ),
    "MeterEventAdjustmentCreateParams": (
        "stripe.params.v2.billing._meter_event_adjustment_create_params",
        False,
    ),
    "MeterEventAdjustmentCreateParamsCancel": (
        "stripe.params.v2.billing._meter_event_adjustment_create_params",
        False,
    ),
    "MeterEventCreateParams": (
        "stripe.params.v2.billing._meter_event_create_params",
        False,
    ),
    "MeterEventSessionCreateParams": (
        "stripe.params.v2.billing._meter_event_session_create_params",
        False,
    ),
    "MeterEventStreamCreateParams": (
        "stripe.params.v2.billing._meter_event_stream_create_params",
        False,
    ),
    "MeterEventStreamCreateParamsEvent": (
        "stripe.params.v2.billing._meter_event_stream_create_params",
        False,
    ),
    "MeteredItemCreateParams": (
        "stripe.params.v2.billing._metered_item_create_params",
        False,
    ),
    "MeteredItemCreateParamsMeterSegmentCondition": (
        "stripe.params.v2.billing._metered_item_create_params",
        False,
    ),
    "MeteredItemCreateParamsTaxDetails": (
        "stripe.params.v2.billing._metered_item_create_params",
        False,
    ),
    "MeteredItemListParams": (
        "stripe.params.v2.billing._metered_item_list_params",
        False,
    ),
    "MeteredItemRetrieveParams": (
        "stripe.params.v2.billing._metered_item_retrieve_params",
        False,
    ),
    "MeteredItemUpdateParams": (
        "stripe.params.v2.billing._metered_item_update_params",
        False,
    ),
    "MeteredItemUpdateParamsTaxDetails": (
        "stripe.params.v2.billing._metered_item_update_params",
        False,
    ),
    "PricingPlanCreateParams": (
        "stripe.params.v2.billing._pricing_plan_create_params",
        False,
    ),
    "PricingPlanListParams": (
        "stripe.params.v2.billing._pricing_plan_list_params",
        False,
    ),
    "PricingPlanRetrieveParams": (
        "stripe.params.v2.billing._pricing_plan_retrieve_params",
        False,
    ),
    "PricingPlanSubscriptionListParams": (
        "stripe.params.v2.billing._pricing_plan_subscription_list_params",
        False,
    ),
    "PricingPlanSubscriptionListParamsPayer": (
        "stripe.params.v2.billing._pricing_plan_subscription_list_params",
        False,
    ),
    "PricingPlanSubscriptionRetrieveParams": (
        "stripe.params.v2.billing._pricing_plan_subscription_retrieve_params",
        False,
    ),
    "PricingPlanSubscriptionUpdateParams": (
        "stripe.params.v2.billing._pricing_plan_subscription_update_params",
        False,
    ),
    "PricingPlanUpdateParams": (
        "stripe.params.v2.billing._pricing_plan_update_params",
        False,
    ),
    "ProfileCreateParams": (
        "stripe.params.v2.billing._profile_create_params",
        False,
    ),
    "ProfileListParams": (
        "stripe.params.v2.billing._profile_list_params",
        False,
    ),
    "ProfileRetrieveParams": (
        "stripe.params.v2.billing._profile_retrieve_params",
        False,
    ),
    "ProfileUpdateParams": (
        "stripe.params.v2.billing._profile_update_params",
        False,
    ),
    "RateCardCreateParams": (
        "stripe.params.v2.billing._rate_card_create_params",
        False,
    ),
    "RateCardListParams": (
        "stripe.params.v2.billing._rate_card_list_params",
        False,
    ),
    "RateCardRetrieveParams": (
        "stripe.params.v2.billing._rate_card_retrieve_params",
        False,
    ),
    "RateCardSubscriptionCancelParams": (
        "stripe.params.v2.billing._rate_card_subscription_cancel_params",
        False,
    ),
    "RateCardSubscriptionCreateParams": (
        "stripe.params.v2.billing._rate_card_subscription_create_params",
        False,
    ),
    "RateCardSubscriptionListParams": (
        "stripe.params.v2.billing._rate_card_subscription_list_params",
        False,
    ),
    "RateCardSubscriptionListParamsPayer": (
        "stripe.params.v2.billing._rate_card_subscription_list_params",
        False,
    ),
    "RateCardSubscriptionRetrieveParams": (
        "stripe.params.v2.billing._rate_card_subscription_retrieve_params",
        False,
    ),
    "RateCardSubscriptionUpdateParams": (
        "stripe.params.v2.billing._rate_card_subscription_update_params",
        False,
    ),
    "RateCardUpdateParams": (
        "stripe.params.v2.billing._rate_card_update_params",
        False,
    ),
    "ServiceActionCreateParams": (
        "stripe.params.v2.billing._service_action_create_params",
        False,
    ),
    "ServiceActionCreateParamsCreditGrant": (
        "stripe.params.v2.billing._service_action_create_params",
        False,
    ),
    "ServiceActionCreateParamsCreditGrantAmount": (
        "stripe.params.v2.billing._service_action_create_params",
        False,
    ),
    "ServiceActionCreateParamsCreditGrantAmountCustomPricingUnit": (
        "stripe.params.v2.billing._service_action_create_params",
        False,
    ),
    "ServiceActionCreateParamsCreditGrantApplicabilityConfig": (
        "stripe.params.v2.billing._service_action_create_params",
        False,
    ),
    "ServiceActionCreateParamsCreditGrantApplicabilityConfigScope": (
        "stripe.params.v2.billing._service_action_create_params",
        False,
    ),
    "ServiceActionCreateParamsCreditGrantExpiryConfig": (
        "stripe.params.v2.billing._service_action_create_params",
        False,
    ),
    "ServiceActionCreateParamsCreditGrantPerTenant": (
        "stripe.params.v2.billing._service_action_create_params",
        False,
    ),
    "ServiceActionCreateParamsCreditGrantPerTenantAmount": (
        "stripe.params.v2.billing._service_action_create_params",
        False,
    ),
    "ServiceActionCreateParamsCreditGrantPerTenantAmountCustomPricingUnit": (
        "stripe.params.v2.billing._service_action_create_params",
        False,
    ),
    "ServiceActionCreateParamsCreditGrantPerTenantApplicabilityConfig": (
        "stripe.params.v2.billing._service_action_create_params",
        False,
    ),
    "ServiceActionCreateParamsCreditGrantPerTenantApplicabilityConfigScope": (
        "stripe.params.v2.billing._service_action_create_params",
        False,
    ),
    "ServiceActionCreateParamsCreditGrantPerTenantExpiryConfig": (
        "stripe.params.v2.billing._service_action_create_params",
        False,
    ),
    "ServiceActionCreateParamsCreditGrantPerTenantGrantCondition": (
        "stripe.params.v2.billing._service_action_create_params",
        False,
    ),
    "ServiceActionCreateParamsCreditGrantPerTenantGrantConditionMeterEventFirstPerPeriod": (
        "stripe.params.v2.billing._service_action_create_params",
        False,
    ),
    "ServiceActionCreateParamsCreditGrantPerTenantGrantConditionMeterEventFirstPerPeriodMeterSegmentCondition": (
        "stripe.params.v2.billing._service_action_create_params",
        False,
    ),
    "ServiceActionCreateParamsCreditGrantPerTenantGrantConditionMeterEventFirstPerPeriodMeterSegmentConditionDimension": (
        "stripe.params.v2.billing._service_action_create_params",
        False,
    ),
    "ServiceActionRetrieveParams": (
        "stripe.params.v2.billing._service_action_retrieve_params",
        False,
    ),
    "ServiceActionUpdateParams": (
        "stripe.params.v2.billing._service_action_update_params",
        False,
    ),
    "ServiceActionUpdateParamsCreditGrant": (
        "stripe.params.v2.billing._service_action_update_params",
        False,
    ),
    "ServiceActionUpdateParamsCreditGrantPerTenant": (
        "stripe.params.v2.billing._service_action_update_params",
        False,
    ),
}
if not TYPE_CHECKING:

    def __getattr__(name):
        try:
            target, is_submodule = _import_map[name]
            module = import_module(target)
            if is_submodule:
                return module

            return getattr(
                module,
                name,
            )
        except KeyError:
            raise AttributeError()



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_service import StripeService
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._request_options import RequestOptions
    from stripe.capital._financing_summary import FinancingSummary
    from stripe.params.capital._financing_summary_retrieve_params import (
        FinancingSummaryRetrieveParams,
    )


class FinancingSummaryService(StripeService):
    def retrieve(
        self,
        params: Optional["FinancingSummaryRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "FinancingSummary":
        """
        Retrieve the financing state for the account that was authenticated in the request.
        """
        return cast(
            "FinancingSummary",
            self._request(
                "get",
                "/v1/capital/financing_summary",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        params: Optional["FinancingSummaryRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "FinancingSummary":
        """
        Retrieve the financing state for the account that was authenticated in the request.
        """
        return cast(
            "FinancingSummary",
            await self._request_async(
                "get",
                "/v1/capital/financing_summary",
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing import Dict, List
from typing_extensions import Literal, NotRequired, TypedDict


class PaymentLinkUpdateParams(TypedDict):
    active: NotRequired[bool]
    """
    Whether the payment link's `url` is active. If `false`, customers visiting the URL will be shown a page saying that the link has been deactivated.
    """
    after_completion: NotRequired["PaymentLinkUpdateParamsAfterCompletion"]
    """
    Behavior after the purchase is complete.
    """
    allow_promotion_codes: NotRequired[bool]
    """
    Enables user redeemable promotion codes.
    """
    automatic_tax: NotRequired["PaymentLinkUpdateParamsAutomaticTax"]
    """
    Configuration for automatic tax collection.
    """
    billing_address_collection: NotRequired[Literal["auto", "required"]]
    """
    Configuration for collecting the customer's billing address. Defaults to `auto`.
    """
    custom_fields: NotRequired[
        "Literal['']|List[PaymentLinkUpdateParamsCustomField]"
    ]
    """
    Collect additional information from your customer using custom fields. Up to 3 fields are supported.
    """
    custom_text: NotRequired["PaymentLinkUpdateParamsCustomText"]
    """
    Display additional text for your customers using custom text.
    """
    customer_creation: NotRequired[Literal["always", "if_required"]]
    """
    Configures whether [checkout sessions](https://stripe.com/docs/api/checkout/sessions) created by this payment link create a [Customer](https://stripe.com/docs/api/customers).
    """
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    inactive_message: NotRequired["Literal['']|str"]
    """
    The custom message to be displayed to a customer when a payment link is no longer active.
    """
    invoice_creation: NotRequired["PaymentLinkUpdateParamsInvoiceCreation"]
    """
    Generate a post-purchase Invoice for one-time payments.
    """
    line_items: NotRequired[List["PaymentLinkUpdateParamsLineItem"]]
    """
    The line items representing what is being sold. Each line item represents an item being sold. Up to 20 line items are supported.
    """
    metadata: NotRequired[Dict[str, str]]
    """
    Set of [key-value pairs](https://stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`. Metadata associated with this Payment Link will automatically be copied to [checkout sessions](https://stripe.com/docs/api/checkout/sessions) created by this payment link.
    """
    name_collection: NotRequired[
        "Literal['']|PaymentLinkUpdateParamsNameCollection"
    ]
    """
    Controls settings applied for collecting the customer's name.
    """
    payment_intent_data: NotRequired[
        "PaymentLinkUpdateParamsPaymentIntentData"
    ]
    """
    A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in `payment` mode.
    """
    payment_method_collection: NotRequired[Literal["always", "if_required"]]
    """
    Specify whether Checkout should collect a payment method. When set to `if_required`, Checkout will not collect a payment method when the total due for the session is 0.This may occur if the Checkout Session includes a free trial or a discount.

    Can only be set in `subscription` mode. Defaults to `always`.

    If you'd like information on how to collect a payment method outside of Checkout, read the guide on [configuring subscriptions with a free trial](https://stripe.com/docs/payments/checkout/free-trials).
    """
    payment_method_types: NotRequired[
        "Literal['']|List[Literal['affirm', 'afterpay_clearpay', 'alipay', 'alma', 'au_becs_debit', 'bacs_debit', 'bancontact', 'billie', 'blik', 'boleto', 'card', 'cashapp', 'eps', 'fpx', 'giropay', 'gopay', 'grabpay', 'ideal', 'klarna', 'konbini', 'link', 'mb_way', 'mobilepay', 'multibanco', 'oxxo', 'p24', 'pay_by_bank', 'paynow', 'paypal', 'paypay', 'payto', 'pix', 'promptpay', 'qris', 'rechnung', 'satispay', 'sepa_debit', 'shopeepay', 'sofort', 'swish', 'twint', 'us_bank_account', 'wechat_pay', 'zip']]"
    ]
    """
    The list of payment method types that customers can use. Pass an empty string to enable dynamic payment methods that use your [payment method settings](https://dashboard.stripe.com/settings/payment_methods).
    """
    phone_number_collection: NotRequired[
        "PaymentLinkUpdateParamsPhoneNumberCollection"
    ]
    """
    Controls phone number collection settings during checkout.

    We recommend that you review your privacy policy and check with your legal contacts.
    """
    restrictions: NotRequired[
        "Literal['']|PaymentLinkUpdateParamsRestrictions"
    ]
    """
    Settings that restrict the usage of a payment link.
    """
    shipping_address_collection: NotRequired[
        "Literal['']|PaymentLinkUpdateParamsShippingAddressCollection"
    ]
    """
    Configuration for collecting the customer's shipping address.
    """
    submit_type: NotRequired[
        Literal["auto", "book", "donate", "pay", "subscribe"]
    ]
    """
    Describes the type of transaction being performed in order to customize relevant text on the page, such as the submit button. Changing this value will also affect the hostname in the [url](https://stripe.com/docs/api/payment_links/payment_links/object#url) property (example: `donate.stripe.com`).
    """
    subscription_data: NotRequired["PaymentLinkUpdateParamsSubscriptionData"]
    """
    When creating a subscription, the specified configuration data will be used. There must be at least one line item with a recurring price to use `subscription_data`.
    """
    tax_id_collection: NotRequired["PaymentLinkUpdateParamsTaxIdCollection"]
    """
    Controls tax ID collection during checkout.
    """


class PaymentLinkUpdateParamsAfterCompletion(TypedDict):
    hosted_confirmation: NotRequired[
        "PaymentLinkUpdateParamsAfterCompletionHostedConfirmation"
    ]
    """
    Configuration when `type=hosted_confirmation`.
    """
    redirect: NotRequired["PaymentLinkUpdateParamsAfterCompletionRedirect"]
    """
    Configuration when `type=redirect`.
    """
    type: Literal["hosted_confirmation", "redirect"]
    """
    The specified behavior after the purchase is complete. Either `redirect` or `hosted_confirmation`.
    """


class PaymentLinkUpdateParamsAfterCompletionHostedConfirmation(TypedDict):
    custom_message: NotRequired[str]
    """
    A custom message to display to the customer after the purchase is complete.
    """


class PaymentLinkUpdateParamsAfterCompletionRedirect(TypedDict):
    url: str
    """
    The URL the customer will be redirected to after the purchase is complete. You can embed `{CHECKOUT_SESSION_ID}` into the URL to have the `id` of the completed [checkout session](https://stripe.com/docs/api/checkout/sessions/object#checkout_session_object-id) included.
    """


class PaymentLinkUpdateParamsAutomaticTax(TypedDict):
    enabled: bool
    """
    Set to `true` to [calculate tax automatically](https://docs.stripe.com/tax) using the customer's location.

    Enabling this parameter causes the payment link to collect any billing address information necessary for tax calculation.
    """
    liability: NotRequired["PaymentLinkUpdateParamsAutomaticTaxLiability"]
    """
    The account that's liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
    """


class PaymentLinkUpdateParamsAutomaticTaxLiability(TypedDict):
    account: NotRequired[str]
    """
    The connected account being referenced when `type` is `account`.
    """
    type: Literal["account", "self"]
    """
    Type of the account referenced in the request.
    """


class PaymentLinkUpdateParamsCustomField(TypedDict):
    dropdown: NotRequired["PaymentLinkUpdateParamsCustomFieldDropdown"]
    """
    Configuration for `type=dropdown` fields.
    """
    key: str
    """
    String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters.
    """
    label: "PaymentLinkUpdateParamsCustomFieldLabel"
    """
    The label for the field, displayed to the customer.
    """
    numeric: NotRequired["PaymentLinkUpdateParamsCustomFieldNumeric"]
    """
    Configuration for `type=numeric` fields.
    """
    optional: NotRequired[bool]
    """
    Whether the customer is required to complete the field before completing the Checkout Session. Defaults to `false`.
    """
    text: NotRequired["PaymentLinkUpdateParamsCustomFieldText"]
    """
    Configuration for `type=text` fields.
    """
    type: Literal["dropdown", "numeric", "text"]
    """
    The type of the field.
    """


class PaymentLinkUpdateParamsCustomFieldDropdown(TypedDict):
    default_value: NotRequired[str]
    """
    The value that will pre-fill the field on the payment page.Must match a `value` in the `options` array.
    """
    options: List["PaymentLinkUpdateParamsCustomFieldDropdownOption"]
    """
    The options available for the customer to select. Up to 200 options allowed.
    """


class PaymentLinkUpdateParamsCustomFieldDropdownOption(TypedDict):
    label: str
    """
    The label for the option, displayed to the customer. Up to 100 characters.
    """
    value: str
    """
    The value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer. Must be unique to this option, alphanumeric, and up to 100 characters.
    """


class PaymentLinkUpdateParamsCustomFieldLabel(TypedDict):
    custom: str
    """
    Custom text for the label, displayed to the customer. Up to 50 characters.
    """
    type: Literal["custom"]
    """
    The type of the label.
    """


class PaymentLinkUpdateParamsCustomFieldNumeric(TypedDict):
    default_value: NotRequired[str]
    """
    The value that will pre-fill the field on the payment page.
    """
    maximum_length: NotRequired[int]
    """
    The maximum character length constraint for the customer's input.
    """
    minimum_length: NotRequired[int]
    """
    The minimum character length requirement for the customer's input.
    """


class PaymentLinkUpdateParamsCustomFieldText(TypedDict):
    default_value: NotRequired[str]
    """
    The value that will pre-fill the field on the payment page.
    """
    maximum_length: NotRequired[int]
    """
    The maximum character length constraint for the customer's input.
    """
    minimum_length: NotRequired[int]
    """
    The minimum character length requirement for the customer's input.
    """


class PaymentLinkUpdateParamsCustomText(TypedDict):
    after_submit: NotRequired[
        "Literal['']|PaymentLinkUpdateParamsCustomTextAfterSubmit"
    ]
    """
    Custom text that should be displayed after the payment confirmation button.
    """
    shipping_address: NotRequired[
        "Literal['']|PaymentLinkUpdateParamsCustomTextShippingAddress"
    ]
    """
    Custom text that should be displayed alongside shipping address collection.
    """
    submit: NotRequired["Literal['']|PaymentLinkUpdateParamsCustomTextSubmit"]
    """
    Custom text that should be displayed alongside the payment confirmation button.
    """
    terms_of_service_acceptance: NotRequired[
        "Literal['']|PaymentLinkUpdateParamsCustomTextTermsOfServiceAcceptance"
    ]
    """
    Custom text that should be displayed in place of the default terms of service agreement text.
    """


class PaymentLinkUpdateParamsCustomTextAfterSubmit(TypedDict):
    message: str
    """
    Text may be up to 1200 characters in length.
    """


class PaymentLinkUpdateParamsCustomTextShippingAddress(TypedDict):
    message: str
    """
    Text may be up to 1200 characters in length.
    """


class PaymentLinkUpdateParamsCustomTextSubmit(TypedDict):
    message: str
    """
    Text may be up to 1200 characters in length.
    """


class PaymentLinkUpdateParamsCustomTextTermsOfServiceAcceptance(TypedDict):
    message: str
    """
    Text may be up to 1200 characters in length.
    """


class PaymentLinkUpdateParamsInvoiceCreation(TypedDict):
    enabled: bool
    """
    Whether the feature is enabled
    """
    invoice_data: NotRequired[
        "PaymentLinkUpdateParamsInvoiceCreationInvoiceData"
    ]
    """
    Invoice PDF configuration.
    """


class PaymentLinkUpdateParamsInvoiceCreationInvoiceData(TypedDict):
    account_tax_ids: NotRequired["Literal['']|List[str]"]
    """
    The account tax IDs associated with the invoice.
    """
    custom_fields: NotRequired[
        "Literal['']|List[PaymentLinkUpdateParamsInvoiceCreationInvoiceDataCustomField]"
    ]
    """
    Default custom fields to be displayed on invoices for this customer.
    """
    description: NotRequired[str]
    """
    An arbitrary string attached to the object. Often useful for displaying to users.
    """
    footer: NotRequired[str]
    """
    Default footer to be displayed on invoices for this customer.
    """
    issuer: NotRequired[
        "PaymentLinkUpdateParamsInvoiceCreationInvoiceDataIssuer"
    ]
    """
    The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
    """
    metadata: NotRequired["Literal['']|Dict[str, str]"]
    """
    Set of [key-value pairs](https://stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.
    """
    rendering_options: NotRequired[
        "Literal['']|PaymentLinkUpdateParamsInvoiceCreationInvoiceDataRenderingOptions"
    ]
    """
    Default options for invoice PDF rendering for this customer.
    """


class PaymentLinkUpdateParamsInvoiceCreationInvoiceDataCustomField(TypedDict):
    name: str
    """
    The name of the custom field. This may be up to 40 characters.
    """
    value: str
    """
    The value of the custom field. This may be up to 140 characters.
    """


class PaymentLinkUpdateParamsInvoiceCreationInvoiceDataIssuer(TypedDict):
    account: NotRequired[str]
    """
    The connected account being referenced when `type` is `account`.
    """
    type: Literal["account", "self"]
    """
    Type of the account referenced in the request.
    """


class PaymentLinkUpdateParamsInvoiceCreationInvoiceDataRenderingOptions(
    TypedDict,
):
    amount_tax_display: NotRequired[
        "Literal['']|Literal['exclude_tax', 'include_inclusive_tax']"
    ]
    """
    How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. One of `exclude_tax` or `include_inclusive_tax`. `include_inclusive_tax` will include inclusive tax (and exclude exclusive tax) in invoice PDF amounts. `exclude_tax` will exclude all tax (inclusive and exclusive alike) from invoice PDF amounts.
    """
    template: NotRequired[str]
    """
    ID of the invoice rendering template to use for this invoice.
    """


class PaymentLinkUpdateParamsLineItem(TypedDict):
    adjustable_quantity: NotRequired[
        "PaymentLinkUpdateParamsLineItemAdjustableQuantity"
    ]
    """
    When set, provides configuration for this item's quantity to be adjusted by the customer during checkout.
    """
    id: str
    """
    The ID of an existing line item on the payment link.
    """
    quantity: NotRequired[int]
    """
    The quantity of the line item being purchased.
    """


class PaymentLinkUpdateParamsLineItemAdjustableQuantity(TypedDict):
    enabled: bool
    """
    Set to true if the quantity can be adjusted to any non-negative Integer.
    """
    maximum: NotRequired[int]
    """
    The maximum quantity the customer can purchase. By default this value is 99. You can specify a value up to 999999.
    """
    minimum: NotRequired[int]
    """
    The minimum quantity the customer can purchase. By default this value is 0. If there is only one item in the cart then that item's quantity cannot go down to 0.
    """


class PaymentLinkUpdateParamsNameCollection(TypedDict):
    business: NotRequired["PaymentLinkUpdateParamsNameCollectionBusiness"]
    """
    Controls settings applied for collecting the customer's business name.
    """
    individual: NotRequired["PaymentLinkUpdateParamsNameCollectionIndividual"]
    """
    Controls settings applied for collecting the customer's individual name.
    """


class PaymentLinkUpdateParamsNameCollectionBusiness(TypedDict):
    enabled: bool
    """
    Enable business name collection on the payment link. Defaults to `false`.
    """
    optional: NotRequired[bool]
    """
    Whether the customer is required to provide their business name before checking out. Defaults to `false`.
    """


class PaymentLinkUpdateParamsNameCollectionIndividual(TypedDict):
    enabled: bool
    """
    Enable individual name collection on the payment link. Defaults to `false`.
    """
    optional: NotRequired[bool]
    """
    Whether the customer is required to provide their full name before checking out. Defaults to `false`.
    """


class PaymentLinkUpdateParamsPaymentIntentData(TypedDict):
    description: NotRequired["Literal['']|str"]
    """
    An arbitrary string attached to the object. Often useful for displaying to users.
    """
    metadata: NotRequired["Literal['']|Dict[str, str]"]
    """
    Set of [key-value pairs](https://stripe.com/docs/api/metadata) that will declaratively set metadata on [Payment Intents](https://stripe.com/docs/api/payment_intents) generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.
    """
    statement_descriptor: NotRequired["Literal['']|str"]
    """
    Text that appears on the customer's statement as the statement descriptor for a non-card charge. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](https://docs.stripe.com/get-started/account/statement-descriptors).

    Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](https://docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.
    """
    statement_descriptor_suffix: NotRequired["Literal['']|str"]
    """
    Provides information about a card charge. Concatenated to the account's [statement descriptor prefix](https://docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer's statement.
    """
    transfer_group: NotRequired["Literal['']|str"]
    """
    A string that identifies the resulting payment as part of a group. See the PaymentIntents [use case for connected accounts](https://stripe.com/docs/connect/separate-charges-and-transfers) for details.
    """


class PaymentLinkUpdateParamsPhoneNumberCollection(TypedDict):
    enabled: bool
    """
    Set to `true` to enable phone number collection.
    """


class PaymentLinkUpdateParamsRestrictions(TypedDict):
    completed_sessions: "PaymentLinkUpdateParamsRestrictionsCompletedSessions"
    """
    Configuration for the `completed_sessions` restriction type.
    """


class PaymentLinkUpdateParamsRestrictionsCompletedSessions(TypedDict):
    limit: int
    """
    The maximum number of checkout sessions that can be completed for the `completed_sessions` restriction to be met.
    """


class PaymentLinkUpdateParamsShippingAddressCollection(TypedDict):
    allowed_countries: List[
        Literal[
            "AC",
            "AD",
            "AE",
            "AF",
            "AG",
            "AI",
            "AL",
            "AM",
            "AO",
            "AQ",
            "AR",
            "AT",
            "AU",
            "AW",
            "AX",
            "AZ",
            "BA",
            "BB",
            "BD",
            "BE",
            "BF",
            "BG",
            "BH",
            "BI",
            "BJ",
            "BL",
            "BM",
            "BN",
            "BO",
            "BQ",
            "BR",
            "BS",
            "BT",
            "BV",
            "BW",
            "BY",
            "BZ",
            "CA",
            "CD",
            "CF",
            "CG",
            "CH",
            "CI",
            "CK",
            "CL",
            "CM",
            "CN",
            "CO",
            "CR",
            "CV",
            "CW",
            "CY",
            "CZ",
            "DE",
            "DJ",
            "DK",
            "DM",
            "DO",
            "DZ",
            "EC",
            "EE",
            "EG",
            "EH",
            "ER",
            "ES",
            "ET",
            "FI",
            "FJ",
            "FK",
            "FO",
            "FR",
            "GA",
            "GB",
            "GD",
            "GE",
            "GF",
            "GG",
            "GH",
            "GI",
            "GL",
            "GM",
            "GN",
            "GP",
            "GQ",
            "GR",
            "GS",
            "GT",
            "GU",
            "GW",
            "GY",
            "HK",
            "HN",
            "HR",
            "HT",
            "HU",
            "ID",
            "IE",
            "IL",
            "IM",
            "IN",
            "IO",
            "IQ",
            "IS",
            "IT",
            "JE",
            "JM",
            "JO",
            "JP",
            "KE",
            "KG",
            "KH",
            "KI",
            "KM",
            "KN",
            "KR",
            "KW",
            "KY",
            "KZ",
            "LA",
            "LB",
            "LC",
            "LI",
            "LK",
            "LR",
            "LS",
            "LT",
            "LU",
            "LV",
            "LY",
            "MA",
            "MC",
            "MD",
            "ME",
            "MF",
            "MG",
            "MK",
            "ML",
            "MM",
            "MN",
            "MO",
            "MQ",
            "MR",
            "MS",
            "MT",
            "MU",
            "MV",
            "MW",
            "MX",
            "MY",
            "MZ",
            "NA",
            "NC",
            "NE",
            "NG",
            "NI",
            "NL",
            "NO",
            "NP",
            "NR",
            "NU",
            "NZ",
            "OM",
            "PA",
            "PE",
            "PF",
            "PG",
            "PH",
            "PK",
            "PL",
            "PM",
            "PN",
            "PR",
            "PS",
            "PT",
            "PY",
            "QA",
            "RE",
            "RO",
            "RS",
            "RU",
            "RW",
            "SA",
            "SB",
            "SC",
            "SD",
            "SE",
            "SG",
            "SH",
            "SI",
            "SJ",
            "SK",
            "SL",
            "SM",
            "SN",
            "SO",
            "SR",
            "SS",
            "ST",
            "SV",
            "SX",
            "SZ",
            "TA",
            "TC",
            "TD",
            "TF",
            "TG",
            "TH",
            "TJ",
            "TK",
            "TL",
            "TM",
            "TN",
            "TO",
            "TR",
            "TT",
            "TV",
            "TW",
            "TZ",
            "UA",
            "UG",
            "US",
            "UY",
            "UZ",
            "VA",
            "VC",
            "VE",
            "VG",
            "VN",
            "VU",
            "WF",
            "WS",
            "XK",
            "YE",
            "YT",
            "ZA",
            "ZM",
            "ZW",
            "ZZ",
        ]
    ]
    """
    An array of two-letter ISO country codes representing which countries Checkout should provide as options for
    shipping locations.
    """


class PaymentLinkUpdateParamsSubscriptionData(TypedDict):
    invoice_settings: NotRequired[
        "PaymentLinkUpdateParamsSubscriptionDataInvoiceSettings"
    ]
    """
    All invoices will be billed using the specified settings.
    """
    metadata: NotRequired["Literal['']|Dict[str, str]"]
    """
    Set of [key-value pairs](https://stripe.com/docs/api/metadata) that will declaratively set metadata on [Subscriptions](https://stripe.com/docs/api/subscriptions) generated from this payment link. Unlike object-level metadata, this field is declarative. Updates will clear prior values.
    """
    trial_period_days: NotRequired["Literal['']|int"]
    """
    Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.
    """
    trial_settings: NotRequired[
        "Literal['']|PaymentLinkUpdateParamsSubscriptionDataTrialSettings"
    ]
    """
    Settings related to subscription trials.
    """


class PaymentLinkUpdateParamsSubscriptionDataInvoiceSettings(TypedDict):
    issuer: NotRequired[
        "PaymentLinkUpdateParamsSubscriptionDataInvoiceSettingsIssuer"
    ]
    """
    The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
    """


class PaymentLinkUpdateParamsSubscriptionDataInvoiceSettingsIssuer(TypedDict):
    account: NotRequired[str]
    """
    The connected account being referenced when `type` is `account`.
    """
    type: Literal["account", "self"]
    """
    Type of the account referenced in the request.
    """


class PaymentLinkUpdateParamsSubscriptionDataTrialSettings(TypedDict):
    end_behavior: (
        "PaymentLinkUpdateParamsSubscriptionDataTrialSettingsEndBehavior"
    )
    """
    Defines how the subscription should behave when the user's free trial ends.
    """


class PaymentLinkUpdateParamsSubscriptionDataTrialSettingsEndBehavior(
    TypedDict,
):
    missing_payment_method: Literal["cancel", "create_invoice", "pause"]
    """
    Indicates how the subscription should change when the trial ends if the user did not provide a payment method.
    """


class PaymentLinkUpdateParamsTaxIdCollection(TypedDict):
    enabled: bool
    """
    Enable tax ID collection during checkout. Defaults to `false`.
    """
    required: NotRequired[Literal["if_supported", "never"]]
    """
    Describes whether a tax ID is required during checkout. Defaults to `never`.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing_extensions import NotRequired, TypedDict


class FinancialAccountCloseParams(TypedDict):
    forwarding_settings: NotRequired[
        "FinancialAccountCloseParamsForwardingSettings"
    ]
    """
    The addresses to forward any incoming transactions to.
    """


class FinancialAccountCloseParamsForwardingSettings(TypedDict):
    payment_method: NotRequired[str]
    """
    The address to send forwarded payments to.
    """
    payout_method: NotRequired[str]
    """
    The address to send forwarded payouts to.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from typing import Optional, cast
from importlib import import_module
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._list_object import ListObject
    from stripe._request_options import RequestOptions
    from stripe.params.privacy._redaction_job_cancel_params import (
        RedactionJobCancelParams,
    )
    from stripe.params.privacy._redaction_job_create_params import (
        RedactionJobCreateParams,
    )
    from stripe.params.privacy._redaction_job_list_params import (
        RedactionJobListParams,
    )
    from stripe.params.privacy._redaction_job_retrieve_params import (
        RedactionJobRetrieveParams,
    )
    from stripe.params.privacy._redaction_job_run_params import (
        RedactionJobRunParams,
    )
    from stripe.params.privacy._redaction_job_update_params import (
        RedactionJobUpdateParams,
    )
    from stripe.params.privacy._redaction_job_validate_params import (
        RedactionJobValidateParams,
    )
    from stripe.privacy._redaction_job import RedactionJob
    from stripe.privacy._redaction_job_validation_error_service import (
        RedactionJobValidationErrorService,
    )

_subservices = {
    "validation_errors": [
        "stripe.privacy._redaction_job_validation_error_service",
        "RedactionJobValidationErrorService",
    ],
}


class RedactionJobService(StripeService):
    validation_errors: "RedactionJobValidationErrorService"

    def __init__(self, requestor):
        super().__init__(requestor)

    def __getattr__(self, name):
        try:
            import_from, service = _subservices[name]
            service_class = getattr(
                import_module(import_from),
                service,
            )
            setattr(
                self,
                name,
                service_class(self._requestor),
            )
            return getattr(self, name)
        except KeyError:
            raise AttributeError()

    def list(
        self,
        params: Optional["RedactionJobListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[RedactionJob]":
        """
        Returns a list of redaction jobs.
        """
        return cast(
            "ListObject[RedactionJob]",
            self._request(
                "get",
                "/v1/privacy/redaction_jobs",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        params: Optional["RedactionJobListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[RedactionJob]":
        """
        Returns a list of redaction jobs.
        """
        return cast(
            "ListObject[RedactionJob]",
            await self._request_async(
                "get",
                "/v1/privacy/redaction_jobs",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def create(
        self,
        params: "RedactionJobCreateParams",
        options: Optional["RequestOptions"] = None,
    ) -> "RedactionJob":
        """
        Creates a redaction job. When a job is created, it will start to validate.
        """
        return cast(
            "RedactionJob",
            self._request(
                "post",
                "/v1/privacy/redaction_jobs",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def create_async(
        self,
        params: "RedactionJobCreateParams",
        options: Optional["RequestOptions"] = None,
    ) -> "RedactionJob":
        """
        Creates a redaction job. When a job is created, it will start to validate.
        """
        return cast(
            "RedactionJob",
            await self._request_async(
                "post",
                "/v1/privacy/redaction_jobs",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def retrieve(
        self,
        job: str,
        params: Optional["RedactionJobRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "RedactionJob":
        """
        Retrieves the details of a previously created redaction job.
        """
        return cast(
            "RedactionJob",
            self._request(
                "get",
                "/v1/privacy/redaction_jobs/{job}".format(
                    job=sanitize_id(job)
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        job: str,
        params: Optional["RedactionJobRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "RedactionJob":
        """
        Retrieves the details of a previously created redaction job.
        """
        return cast(
            "RedactionJob",
            await self._request_async(
                "get",
                "/v1/privacy/redaction_jobs/{job}".format(
                    job=sanitize_id(job)
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def update(
        self,
        job: str,
        params: Optional["RedactionJobUpdateParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "RedactionJob":
        """
        Updates the properties of a redaction job without running or canceling the job.

        If the job to update is in a failed status, it will not automatically start to validate. Once you applied all of the changes, use the validate API to start validation again.
        """
        return cast(
            "RedactionJob",
            self._request(
                "post",
                "/v1/privacy/redaction_jobs/{job}".format(
                    job=sanitize_id(job)
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def update_async(
        self,
        job: str,
        params: Optional["RedactionJobUpdateParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "RedactionJob":
        """
        Updates the properties of a redaction job without running or canceling the job.

        If the job to update is in a failed status, it will not automatically start to validate. Once you applied all of the changes, use the validate API to start validation again.
        """
        return cast(
            "RedactionJob",
            await self._request_async(
                "post",
                "/v1/privacy/redaction_jobs/{job}".format(
                    job=sanitize_id(job)
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def cancel(
        self,
        job: str,
        params: Optional["RedactionJobCancelParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "RedactionJob":
        """
        You can cancel a redaction job when it's in one of these statuses: ready, failed.

        Canceling the redaction job will abandon its attempt to redact the configured objects. A canceled job cannot be used again.
        """
        return cast(
            "RedactionJob",
            self._request(
                "post",
                "/v1/privacy/redaction_jobs/{job}/cancel".format(
                    job=sanitize_id(job),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def cancel_async(
        self,
        job: str,
        params: Optional["RedactionJobCancelParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "RedactionJob":
        """
        You can cancel a redaction job when it's in one of these statuses: ready, failed.

        Canceling the redaction job will abandon its attempt to redact the configured objects. A canceled job cannot be used again.
        """
        return cast(
            "RedactionJob",
            await self._request_async(
                "post",
                "/v1/privacy/redaction_jobs/{job}/cancel".format(
                    job=sanitize_id(job),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def run(
        self,
        job: str,
        params: Optional["RedactionJobRunParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "RedactionJob":
        """
        Run a redaction job in a ready status.

        When you run a job, the configured objects will be redacted asynchronously. This action is irreversible and cannot be canceled once started.

        The status of the job will move to redacting. Once all of the objects are redacted, the status will become succeeded. If the job's validation_behavior is set to fix, the automatic fixes will be applied to objects at this step.
        """
        return cast(
            "RedactionJob",
            self._request(
                "post",
                "/v1/privacy/redaction_jobs/{job}/run".format(
                    job=sanitize_id(job),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def run_async(
        self,
        job: str,
        params: Optional["RedactionJobRunParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "RedactionJob":
        """
        Run a redaction job in a ready status.

        When you run a job, the configured objects will be redacted asynchronously. This action is irreversible and cannot be canceled once started.

        The status of the job will move to redacting. Once all of the objects are redacted, the status will become succeeded. If the job's validation_behavior is set to fix, the automatic fixes will be applied to objects at this step.
        """
        return cast(
            "RedactionJob",
            await self._request_async(
                "post",
                "/v1/privacy/redaction_jobs/{job}/run".format(
                    job=sanitize_id(job),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def validate(
        self,
        job: str,
        params: Optional["RedactionJobValidateParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "RedactionJob":
        """
        Validate a redaction job when it is in a failed status.

        When a job is created, it automatically begins to validate on the configured objects' eligibility for redaction. Use this to validate the job again after its validation errors are resolved or the job's validation_behavior is changed.

        The status of the job will move to validating. Once all of the objects are validated, the status of the job will become ready. If there are any validation errors preventing the job from running, the status will become failed.
        """
        return cast(
            "RedactionJob",
            self._request(
                "post",
                "/v1/privacy/redaction_jobs/{job}/validate".format(
                    job=sanitize_id(job),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def validate_async(
        self,
        job: str,
        params: Optional["RedactionJobValidateParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "RedactionJob":
        """
        Validate a redaction job when it is in a failed status.

        When a job is created, it automatically begins to validate on the configured objects' eligibility for redaction. Use this to validate the job again after its validation errors are resolved or the job's validation_behavior is changed.

        The status of the job will move to validating. Once all of the objects are validated, the status of the job will become ready. If there are any validation errors preventing the job from running, the status will become failed.
        """
        return cast(
            "RedactionJob",
            await self._request_async(
                "post",
                "/v1/privacy/redaction_jobs/{job}/validate".format(
                    job=sanitize_id(job),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._list_object import ListObject
    from stripe._payment_attempt_record import PaymentAttemptRecord
    from stripe._request_options import RequestOptions
    from stripe.params._payment_attempt_record_list_params import (
        PaymentAttemptRecordListParams,
    )
    from stripe.params._payment_attempt_record_retrieve_params import (
        PaymentAttemptRecordRetrieveParams,
    )


class PaymentAttemptRecordService(StripeService):
    def list(
        self,
        params: "PaymentAttemptRecordListParams",
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[PaymentAttemptRecord]":
        """
        List all the Payment Attempt Records attached to the specified Payment Record.
        """
        return cast(
            "ListObject[PaymentAttemptRecord]",
            self._request(
                "get",
                "/v1/payment_attempt_records",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        params: "PaymentAttemptRecordListParams",
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[PaymentAttemptRecord]":
        """
        List all the Payment Attempt Records attached to the specified Payment Record.
        """
        return cast(
            "ListObject[PaymentAttemptRecord]",
            await self._request_async(
                "get",
                "/v1/payment_attempt_records",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def retrieve(
        self,
        id: str,
        params: Optional["PaymentAttemptRecordRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "PaymentAttemptRecord":
        """
        Retrieves a Payment Attempt Record with the given ID
        """
        return cast(
            "PaymentAttemptRecord",
            self._request(
                "get",
                "/v1/payment_attempt_records/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        id: str,
        params: Optional["PaymentAttemptRecordRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "PaymentAttemptRecord":
        """
        Retrieves a Payment Attempt Record with the given ID
        """
        return cast(
            "PaymentAttemptRecord",
            await self._request_async(
                "get",
                "/v1/payment_attempt_records/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._balance_transaction import BalanceTransaction
    from stripe._list_object import ListObject
    from stripe._request_options import RequestOptions
    from stripe.params._balance_transaction_list_params import (
        BalanceTransactionListParams,
    )
    from stripe.params._balance_transaction_retrieve_params import (
        BalanceTransactionRetrieveParams,
    )


class BalanceTransactionService(StripeService):
    def list(
        self,
        params: Optional["BalanceTransactionListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[BalanceTransaction]":
        """
        Returns a list of transactions that have contributed to the Stripe account balance (e.g., charges, transfers, and so forth). The transactions are returned in sorted order, with the most recent transactions appearing first.

        Note that this endpoint was previously called “Balance history” and used the path /v1/balance/history.
        """
        return cast(
            "ListObject[BalanceTransaction]",
            self._request(
                "get",
                "/v1/balance_transactions",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        params: Optional["BalanceTransactionListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[BalanceTransaction]":
        """
        Returns a list of transactions that have contributed to the Stripe account balance (e.g., charges, transfers, and so forth). The transactions are returned in sorted order, with the most recent transactions appearing first.

        Note that this endpoint was previously called “Balance history” and used the path /v1/balance/history.
        """
        return cast(
            "ListObject[BalanceTransaction]",
            await self._request_async(
                "get",
                "/v1/balance_transactions",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def retrieve(
        self,
        id: str,
        params: Optional["BalanceTransactionRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "BalanceTransaction":
        """
        Retrieves the balance transaction with the given ID.

        Note that this endpoint previously used the path /v1/balance/history/:id.
        """
        return cast(
            "BalanceTransaction",
            self._request(
                "get",
                "/v1/balance_transactions/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        id: str,
        params: Optional["BalanceTransactionRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "BalanceTransaction":
        """
        Retrieves the balance transaction with the given ID.

        Note that this endpoint previously used the path /v1/balance/history/:id.
        """
        return cast(
            "BalanceTransaction",
            await self._request_async(
                "get",
                "/v1/balance_transactions/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-

import json
from collections import OrderedDict

from stripe import (
    DEFAULT_API_BASE,
    DEFAULT_CONNECT_API_BASE,
    DEFAULT_UPLOAD_API_BASE,
    DEFAULT_METER_EVENTS_API_BASE,
)

from stripe._api_mode import ApiMode
from stripe._error import AuthenticationError
from stripe._request_options import extract_options_from_dict
from stripe._requestor_options import RequestorOptions, BaseAddresses
from stripe._client_options import _ClientOptions
from stripe._http_client import (
    new_default_http_client,
    new_http_client_async_fallback,
)
from stripe._api_version import _ApiVersion
from stripe._stripe_object import StripeObject
from stripe._stripe_response import StripeResponse
from stripe._util import _convert_to_stripe_object, get_api_mode, deprecated  # noqa: F401
from stripe._webhook import Webhook, WebhookSignature
from stripe._event import Event
from stripe.v2.core._event import EventNotification

from typing import Any, Dict, Optional, Union, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._stripe_context import StripeContext
    from stripe._http_client import HTTPClient

# Non-generated services
from stripe._oauth_service import OAuthService

from stripe._v1_services import V1Services
from stripe._v2_services import V2Services

# service-types: The beginning of the section generated from our OpenAPI spec
if TYPE_CHECKING:
    from stripe._account_service import AccountService
    from stripe._account_link_service import AccountLinkService
    from stripe._account_notice_service import AccountNoticeService
    from stripe._account_session_service import AccountSessionService
    from stripe._apple_pay_domain_service import ApplePayDomainService
    from stripe._application_fee_service import ApplicationFeeService
    from stripe._apps_service import AppsService
    from stripe._balance_service import BalanceService
    from stripe._balance_settings_service import BalanceSettingsService
    from stripe._balance_transaction_service import BalanceTransactionService
    from stripe._balance_transfer_service import BalanceTransferService
    from stripe._billing_service import BillingService
    from stripe._billing_portal_service import BillingPortalService
    from stripe._capital_service import CapitalService
    from stripe._charge_service import ChargeService
    from stripe._checkout_service import CheckoutService
    from stripe._climate_service import ClimateService
    from stripe._confirmation_token_service import ConfirmationTokenService
    from stripe._country_spec_service import CountrySpecService
    from stripe._coupon_service import CouponService
    from stripe._credit_note_service import CreditNoteService
    from stripe._customer_service import CustomerService
    from stripe._customer_session_service import CustomerSessionService
    from stripe._delegated_checkout_service import DelegatedCheckoutService
    from stripe._dispute_service import DisputeService
    from stripe._entitlements_service import EntitlementsService
    from stripe._ephemeral_key_service import EphemeralKeyService
    from stripe._event_service import EventService
    from stripe._exchange_rate_service import ExchangeRateService
    from stripe._external_account_service import ExternalAccountService
    from stripe._file_service import FileService
    from stripe._file_link_service import FileLinkService
    from stripe._financial_connections_service import (
        FinancialConnectionsService,
    )
    from stripe._forwarding_service import ForwardingService
    from stripe._fx_quote_service import FxQuoteService
    from stripe._identity_service import IdentityService
    from stripe._invoice_service import InvoiceService
    from stripe._invoice_item_service import InvoiceItemService
    from stripe._invoice_payment_service import InvoicePaymentService
    from stripe._invoice_rendering_template_service import (
        InvoiceRenderingTemplateService,
    )
    from stripe._issuing_service import IssuingService
    from stripe._mandate_service import MandateService
    from stripe._margin_service import MarginService
    from stripe._order_service import OrderService
    from stripe._payment_attempt_record_service import (
        PaymentAttemptRecordService,
    )
    from stripe._payment_intent_service import PaymentIntentService
    from stripe._payment_link_service import PaymentLinkService
    from stripe._payment_method_service import PaymentMethodService
    from stripe._payment_method_configuration_service import (
        PaymentMethodConfigurationService,
    )
    from stripe._payment_method_domain_service import (
        PaymentMethodDomainService,
    )
    from stripe._payment_record_service import PaymentRecordService
    from stripe._payout_service import PayoutService
    from stripe._plan_service import PlanService
    from stripe._price_service import PriceService
    from stripe._privacy_service import PrivacyService
    from stripe._product_service import ProductService
    from stripe._promotion_code_service import PromotionCodeService
    from stripe._quote_service import QuoteService
    from stripe._radar_service import RadarService
    from stripe._refund_service import RefundService
    from stripe._reporting_service import ReportingService
    from stripe._review_service import ReviewService
    from stripe._setup_attempt_service import SetupAttemptService
    from stripe._setup_intent_service import SetupIntentService
    from stripe._shipping_rate_service import ShippingRateService
    from stripe._sigma_service import SigmaService
    from stripe._source_service import SourceService
    from stripe._subscription_service import SubscriptionService
    from stripe._subscription_item_service import SubscriptionItemService
    from stripe._subscription_schedule_service import (
        SubscriptionScheduleService,
    )
    from stripe._tax_service import TaxService
    from stripe._tax_code_service import TaxCodeService
    from stripe._tax_id_service import TaxIdService
    from stripe._tax_rate_service import TaxRateService
    from stripe._terminal_service import TerminalService
    from stripe._test_helpers_service import TestHelpersService
    from stripe._token_service import TokenService
    from stripe._topup_service import TopupService
    from stripe._transfer_service import TransferService
    from stripe._treasury_service import TreasuryService
    from stripe._webhook_endpoint_service import WebhookEndpointService

# service-types: The end of the section generated from our OpenAPI spec

if TYPE_CHECKING:
    from stripe.events._event_classes import ALL_EVENT_NOTIFICATIONS


class StripeClient(object):
    def __init__(
        self,
        api_key: str,
        *,
        stripe_account: Optional[str] = None,
        stripe_context: "Optional[Union[str, StripeContext]]" = None,
        stripe_version: Optional[str] = None,
        base_addresses: Optional[BaseAddresses] = None,
        client_id: Optional[str] = None,
        verify_ssl_certs: bool = True,
        proxy: Optional[str] = None,
        max_network_retries: Optional[int] = None,
        http_client: Optional["HTTPClient"] = None,
    ):
        # The types forbid this, but let's give users without types a friendly error.
        if api_key is None:  # pyright: ignore[reportUnnecessaryComparison]
            raise AuthenticationError(
                "No API key provided. (HINT: set your API key using "
                '"client = stripe.StripeClient(<API-KEY>)"). You can '
                "generate API keys from the Stripe web interface. "
                "See https://stripe.com/api for details, or email "
                "support@stripe.com if you have any questions."
            )

        if http_client and (proxy or verify_ssl_certs is not True):
            raise ValueError(
                "You cannot specify `proxy` or `verify_ssl_certs` when passing "
                "in a custom `http_client`. Please set these values on your "
                "custom `http_client` instead."
            )

        # Default to stripe.DEFAULT_API_BASE, stripe.DEFAULT_CONNECT_API_BASE,
        # and stripe.DEFAULT_UPLOAD_API_BASE if not set in base_addresses.
        base_addresses = {
            "api": DEFAULT_API_BASE,
            "connect": DEFAULT_CONNECT_API_BASE,
            "files": DEFAULT_UPLOAD_API_BASE,
            "meter_events": DEFAULT_METER_EVENTS_API_BASE,
            **(base_addresses or {}),
        }

        requestor_options = RequestorOptions(
            api_key=api_key,
            stripe_account=stripe_account,
            stripe_context=stripe_context,
            stripe_version=stripe_version or _ApiVersion.CURRENT,
            base_addresses=base_addresses,
            max_network_retries=max_network_retries,
        )

        if http_client is None:
            http_client = new_default_http_client(
                async_fallback_client=new_http_client_async_fallback(
                    proxy=proxy, verify_ssl_certs=verify_ssl_certs
                ),
                proxy=proxy,
                verify_ssl_certs=verify_ssl_certs,
            )

        from stripe._api_requestor import _APIRequestor

        self._requestor = _APIRequestor(
            options=requestor_options,
            client=http_client,
        )

        self._options = _ClientOptions(
            client_id=client_id,
            proxy=proxy,
            verify_ssl_certs=verify_ssl_certs,
        )

        self.oauth = OAuthService(self._requestor, self._options)

        # top-level services: The beginning of the section generated from our OpenAPI spec
        self.v1 = V1Services(self._requestor)
        self.v2 = V2Services(self._requestor)
        # top-level services: The end of the section generated from our OpenAPI spec

    def parse_event_notification(
        self,
        raw: Union[bytes, str, bytearray],
        sig_header: str,
        secret: str,
        tolerance: int = Webhook.DEFAULT_TOLERANCE,
    ) -> "ALL_EVENT_NOTIFICATIONS":
        """
        This should be your main method for interacting with `EventNotifications`. It's the V2 equivalent of `construct_event()`, but with better typing support.

        It returns a union representing all known `EventNotification` classes. They have a `type` property that can be used for narrowing, which will get you very specific type support. If parsing an event the SDK isn't familiar with, it'll instead return `UnknownEventNotification`. That's not reflected in the return type of the function (because it messes up type narrowing) but is otherwise intended.
        """
        payload = (
            cast(Union[bytes, bytearray], raw).decode("utf-8")
            if hasattr(raw, "decode")
            else cast(str, raw)
        )

        WebhookSignature.verify_header(payload, sig_header, secret, tolerance)

        return cast(
            "ALL_EVENT_NOTIFICATIONS",
            EventNotification.from_json(payload, self),
        )

    def construct_event(
        self,
        payload: Union[bytes, str],
        sig_header: str,
        secret: str,
        tolerance: int = Webhook.DEFAULT_TOLERANCE,
    ) -> Event:
        if hasattr(payload, "decode"):
            payload = cast(bytes, payload).decode("utf-8")

        WebhookSignature.verify_header(payload, sig_header, secret, tolerance)

        data = json.loads(payload, object_pairs_hook=OrderedDict)
        event = Event._construct_from(
            values=data,
            requestor=self._requestor,
            api_mode="V1",
        )

        return event

    def raw_request(self, method_: str, url_: str, **params):
        params = params.copy()
        options, params = extract_options_from_dict(params)
        api_mode = get_api_mode(url_)
        base_address = params.pop("base", "api")

        # we manually pass usage in event internals, so use those if available
        usage = params.pop("usage", ["raw_request"])

        rbody, rcode, rheaders = self._requestor.request_raw(
            method_,
            url_,
            params=params,
            options=options,
            base_address=base_address,
            api_mode=api_mode,
            usage=usage,
        )

        return self._requestor._interpret_response(
            rbody, rcode, rheaders, api_mode
        )

    async def raw_request_async(self, method_: str, url_: str, **params):
        params = params.copy()
        options, params = extract_options_from_dict(params)
        api_mode = get_api_mode(url_)
        base_address = params.pop("base", "api")

        rbody, rcode, rheaders = await self._requestor.request_raw_async(
            method_,
            url_,
            params=params,
            options=options,
            base_address=base_address,
            api_mode=api_mode,
            usage=["raw_request"],
        )

        return self._requestor._interpret_response(
            rbody, rcode, rheaders, api_mode
        )

    def deserialize(
        self,
        resp: Union[StripeResponse, Dict[str, Any]],
        params: Optional[Dict[str, Any]] = None,
        *,
        api_mode: ApiMode,
    ) -> StripeObject:
        """
        Used to translate the result of a `raw_request` into a StripeObject.
        """
        return _convert_to_stripe_object(
            resp=resp,
            params=params,
            requestor=self._requestor,
            api_mode=api_mode,
        )

    # deprecated v1 services: The beginning of the section generated from our OpenAPI spec
    @property
    @deprecated(
        """
        StripeClient.accounts is deprecated, use StripeClient.v1.accounts instead.
          All functionality under it has been copied over to StripeClient.v1.accounts.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def accounts(self) -> "AccountService":
        return self.v1.accounts

    @property
    @deprecated(
        """
        StripeClient.account_links is deprecated, use StripeClient.v1.account_links instead.
          All functionality under it has been copied over to StripeClient.v1.account_links.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def account_links(self) -> "AccountLinkService":
        return self.v1.account_links

    @property
    @deprecated(
        """
        StripeClient.account_notices is deprecated, use StripeClient.v1.account_notices instead.
          All functionality under it has been copied over to StripeClient.v1.account_notices.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def account_notices(self) -> "AccountNoticeService":
        return self.v1.account_notices

    @property
    @deprecated(
        """
        StripeClient.account_sessions is deprecated, use StripeClient.v1.account_sessions instead.
          All functionality under it has been copied over to StripeClient.v1.account_sessions.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def account_sessions(self) -> "AccountSessionService":
        return self.v1.account_sessions

    @property
    @deprecated(
        """
        StripeClient.apple_pay_domains is deprecated, use StripeClient.v1.apple_pay_domains instead.
          All functionality under it has been copied over to StripeClient.v1.apple_pay_domains.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def apple_pay_domains(self) -> "ApplePayDomainService":
        return self.v1.apple_pay_domains

    @property
    @deprecated(
        """
        StripeClient.application_fees is deprecated, use StripeClient.v1.application_fees instead.
          All functionality under it has been copied over to StripeClient.v1.application_fees.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def application_fees(self) -> "ApplicationFeeService":
        return self.v1.application_fees

    @property
    @deprecated(
        """
        StripeClient.apps is deprecated, use StripeClient.v1.apps instead.
          All functionality under it has been copied over to StripeClient.v1.apps.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def apps(self) -> "AppsService":
        return self.v1.apps

    @property
    @deprecated(
        """
        StripeClient.balance is deprecated, use StripeClient.v1.balance instead.
          All functionality under it has been copied over to StripeClient.v1.balance.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def balance(self) -> "BalanceService":
        return self.v1.balance

    @property
    @deprecated(
        """
        StripeClient.balance_settings is deprecated, use StripeClient.v1.balance_settings instead.
          All functionality under it has been copied over to StripeClient.v1.balance_settings.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def balance_settings(self) -> "BalanceSettingsService":
        return self.v1.balance_settings

    @property
    @deprecated(
        """
        StripeClient.balance_transactions is deprecated, use StripeClient.v1.balance_transactions instead.
          All functionality under it has been copied over to StripeClient.v1.balance_transactions.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def balance_transactions(self) -> "BalanceTransactionService":
        return self.v1.balance_transactions

    @property
    @deprecated(
        """
        StripeClient.balance_transfers is deprecated, use StripeClient.v1.balance_transfers instead.
          All functionality under it has been copied over to StripeClient.v1.balance_transfers.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def balance_transfers(self) -> "BalanceTransferService":
        return self.v1.balance_transfers

    @property
    @deprecated(
        """
        StripeClient.billing is deprecated, use StripeClient.v1.billing instead.
          All functionality under it has been copied over to StripeClient.v1.billing.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def billing(self) -> "BillingService":
        return self.v1.billing

    @property
    @deprecated(
        """
        StripeClient.billing_portal is deprecated, use StripeClient.v1.billing_portal instead.
          All functionality under it has been copied over to StripeClient.v1.billing_portal.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def billing_portal(self) -> "BillingPortalService":
        return self.v1.billing_portal

    @property
    @deprecated(
        """
        StripeClient.capital is deprecated, use StripeClient.v1.capital instead.
          All functionality under it has been copied over to StripeClient.v1.capital.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def capital(self) -> "CapitalService":
        return self.v1.capital

    @property
    @deprecated(
        """
        StripeClient.charges is deprecated, use StripeClient.v1.charges instead.
          All functionality under it has been copied over to StripeClient.v1.charges.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def charges(self) -> "ChargeService":
        return self.v1.charges

    @property
    @deprecated(
        """
        StripeClient.checkout is deprecated, use StripeClient.v1.checkout instead.
          All functionality under it has been copied over to StripeClient.v1.checkout.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def checkout(self) -> "CheckoutService":
        return self.v1.checkout

    @property
    @deprecated(
        """
        StripeClient.climate is deprecated, use StripeClient.v1.climate instead.
          All functionality under it has been copied over to StripeClient.v1.climate.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def climate(self) -> "ClimateService":
        return self.v1.climate

    @property
    @deprecated(
        """
        StripeClient.confirmation_tokens is deprecated, use StripeClient.v1.confirmation_tokens instead.
          All functionality under it has been copied over to StripeClient.v1.confirmation_tokens.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def confirmation_tokens(self) -> "ConfirmationTokenService":
        return self.v1.confirmation_tokens

    @property
    @deprecated(
        """
        StripeClient.country_specs is deprecated, use StripeClient.v1.country_specs instead.
          All functionality under it has been copied over to StripeClient.v1.country_specs.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def country_specs(self) -> "CountrySpecService":
        return self.v1.country_specs

    @property
    @deprecated(
        """
        StripeClient.coupons is deprecated, use StripeClient.v1.coupons instead.
          All functionality under it has been copied over to StripeClient.v1.coupons.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def coupons(self) -> "CouponService":
        return self.v1.coupons

    @property
    @deprecated(
        """
        StripeClient.credit_notes is deprecated, use StripeClient.v1.credit_notes instead.
          All functionality under it has been copied over to StripeClient.v1.credit_notes.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def credit_notes(self) -> "CreditNoteService":
        return self.v1.credit_notes

    @property
    @deprecated(
        """
        StripeClient.customers is deprecated, use StripeClient.v1.customers instead.
          All functionality under it has been copied over to StripeClient.v1.customers.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def customers(self) -> "CustomerService":
        return self.v1.customers

    @property
    @deprecated(
        """
        StripeClient.customer_sessions is deprecated, use StripeClient.v1.customer_sessions instead.
          All functionality under it has been copied over to StripeClient.v1.customer_sessions.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def customer_sessions(self) -> "CustomerSessionService":
        return self.v1.customer_sessions

    @property
    @deprecated(
        """
        StripeClient.delegated_checkout is deprecated, use StripeClient.v1.delegated_checkout instead.
          All functionality under it has been copied over to StripeClient.v1.delegated_checkout.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def delegated_checkout(self) -> "DelegatedCheckoutService":
        return self.v1.delegated_checkout

    @property
    @deprecated(
        """
        StripeClient.disputes is deprecated, use StripeClient.v1.disputes instead.
          All functionality under it has been copied over to StripeClient.v1.disputes.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def disputes(self) -> "DisputeService":
        return self.v1.disputes

    @property
    @deprecated(
        """
        StripeClient.entitlements is deprecated, use StripeClient.v1.entitlements instead.
          All functionality under it has been copied over to StripeClient.v1.entitlements.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def entitlements(self) -> "EntitlementsService":
        return self.v1.entitlements

    @property
    @deprecated(
        """
        StripeClient.ephemeral_keys is deprecated, use StripeClient.v1.ephemeral_keys instead.
          All functionality under it has been copied over to StripeClient.v1.ephemeral_keys.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def ephemeral_keys(self) -> "EphemeralKeyService":
        return self.v1.ephemeral_keys

    @property
    @deprecated(
        """
        StripeClient.events is deprecated, use StripeClient.v1.events instead.
          All functionality under it has been copied over to StripeClient.v1.events.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def events(self) -> "EventService":
        return self.v1.events

    @property
    @deprecated(
        """
        StripeClient.exchange_rates is deprecated, use StripeClient.v1.exchange_rates instead.
          All functionality under it has been copied over to StripeClient.v1.exchange_rates.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def exchange_rates(self) -> "ExchangeRateService":
        return self.v1.exchange_rates

    @property
    @deprecated(
        """
        StripeClient.external_accounts is deprecated, use StripeClient.v1.external_accounts instead.
          All functionality under it has been copied over to StripeClient.v1.external_accounts.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def external_accounts(self) -> "ExternalAccountService":
        return self.v1.external_accounts

    @property
    @deprecated(
        """
        StripeClient.files is deprecated, use StripeClient.v1.files instead.
          All functionality under it has been copied over to StripeClient.v1.files.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def files(self) -> "FileService":
        return self.v1.files

    @property
    @deprecated(
        """
        StripeClient.file_links is deprecated, use StripeClient.v1.file_links instead.
          All functionality under it has been copied over to StripeClient.v1.file_links.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def file_links(self) -> "FileLinkService":
        return self.v1.file_links

    @property
    @deprecated(
        """
        StripeClient.financial_connections is deprecated, use StripeClient.v1.financial_connections instead.
          All functionality under it has been copied over to StripeClient.v1.financial_connections.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def financial_connections(self) -> "FinancialConnectionsService":
        return self.v1.financial_connections

    @property
    @deprecated(
        """
        StripeClient.forwarding is deprecated, use StripeClient.v1.forwarding instead.
          All functionality under it has been copied over to StripeClient.v1.forwarding.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def forwarding(self) -> "ForwardingService":
        return self.v1.forwarding

    @property
    @deprecated(
        """
        StripeClient.fx_quotes is deprecated, use StripeClient.v1.fx_quotes instead.
          All functionality under it has been copied over to StripeClient.v1.fx_quotes.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def fx_quotes(self) -> "FxQuoteService":
        return self.v1.fx_quotes

    @property
    @deprecated(
        """
        StripeClient.identity is deprecated, use StripeClient.v1.identity instead.
          All functionality under it has been copied over to StripeClient.v1.identity.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def identity(self) -> "IdentityService":
        return self.v1.identity

    @property
    @deprecated(
        """
        StripeClient.invoices is deprecated, use StripeClient.v1.invoices instead.
          All functionality under it has been copied over to StripeClient.v1.invoices.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def invoices(self) -> "InvoiceService":
        return self.v1.invoices

    @property
    @deprecated(
        """
        StripeClient.invoice_items is deprecated, use StripeClient.v1.invoice_items instead.
          All functionality under it has been copied over to StripeClient.v1.invoice_items.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def invoice_items(self) -> "InvoiceItemService":
        return self.v1.invoice_items

    @property
    @deprecated(
        """
        StripeClient.invoice_payments is deprecated, use StripeClient.v1.invoice_payments instead.
          All functionality under it has been copied over to StripeClient.v1.invoice_payments.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def invoice_payments(self) -> "InvoicePaymentService":
        return self.v1.invoice_payments

    @property
    @deprecated(
        """
        StripeClient.invoice_rendering_templates is deprecated, use StripeClient.v1.invoice_rendering_templates instead.
          All functionality under it has been copied over to StripeClient.v1.invoice_rendering_templates.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def invoice_rendering_templates(self) -> "InvoiceRenderingTemplateService":
        return self.v1.invoice_rendering_templates

    @property
    @deprecated(
        """
        StripeClient.issuing is deprecated, use StripeClient.v1.issuing instead.
          All functionality under it has been copied over to StripeClient.v1.issuing.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def issuing(self) -> "IssuingService":
        return self.v1.issuing

    @property
    @deprecated(
        """
        StripeClient.mandates is deprecated, use StripeClient.v1.mandates instead.
          All functionality under it has been copied over to StripeClient.v1.mandates.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def mandates(self) -> "MandateService":
        return self.v1.mandates

    @property
    @deprecated(
        """
        StripeClient.margins is deprecated, use StripeClient.v1.margins instead.
          All functionality under it has been copied over to StripeClient.v1.margins.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def margins(self) -> "MarginService":
        return self.v1.margins

    @property
    @deprecated(
        """
        StripeClient.orders is deprecated, use StripeClient.v1.orders instead.
          All functionality under it has been copied over to StripeClient.v1.orders.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def orders(self) -> "OrderService":
        return self.v1.orders

    @property
    @deprecated(
        """
        StripeClient.payment_attempt_records is deprecated, use StripeClient.v1.payment_attempt_records instead.
          All functionality under it has been copied over to StripeClient.v1.payment_attempt_records.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def payment_attempt_records(self) -> "PaymentAttemptRecordService":
        return self.v1.payment_attempt_records

    @property
    @deprecated(
        """
        StripeClient.payment_intents is deprecated, use StripeClient.v1.payment_intents instead.
          All functionality under it has been copied over to StripeClient.v1.payment_intents.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def payment_intents(self) -> "PaymentIntentService":
        return self.v1.payment_intents

    @property
    @deprecated(
        """
        StripeClient.payment_links is deprecated, use StripeClient.v1.payment_links instead.
          All functionality under it has been copied over to StripeClient.v1.payment_links.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def payment_links(self) -> "PaymentLinkService":
        return self.v1.payment_links

    @property
    @deprecated(
        """
        StripeClient.payment_methods is deprecated, use StripeClient.v1.payment_methods instead.
          All functionality under it has been copied over to StripeClient.v1.payment_methods.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def payment_methods(self) -> "PaymentMethodService":
        return self.v1.payment_methods

    @property
    @deprecated(
        """
        StripeClient.payment_method_configurations is deprecated, use StripeClient.v1.payment_method_configurations instead.
          All functionality under it has been copied over to StripeClient.v1.payment_method_configurations.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def payment_method_configurations(
        self,
    ) -> "PaymentMethodConfigurationService":
        return self.v1.payment_method_configurations

    @property
    @deprecated(
        """
        StripeClient.payment_method_domains is deprecated, use StripeClient.v1.payment_method_domains instead.
          All functionality under it has been copied over to StripeClient.v1.payment_method_domains.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def payment_method_domains(self) -> "PaymentMethodDomainService":
        return self.v1.payment_method_domains

    @property
    @deprecated(
        """
        StripeClient.payment_records is deprecated, use StripeClient.v1.payment_records instead.
          All functionality under it has been copied over to StripeClient.v1.payment_records.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def payment_records(self) -> "PaymentRecordService":
        return self.v1.payment_records

    @property
    @deprecated(
        """
        StripeClient.payouts is deprecated, use StripeClient.v1.payouts instead.
          All functionality under it has been copied over to StripeClient.v1.payouts.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def payouts(self) -> "PayoutService":
        return self.v1.payouts

    @property
    @deprecated(
        """
        StripeClient.plans is deprecated, use StripeClient.v1.plans instead.
          All functionality under it has been copied over to StripeClient.v1.plans.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def plans(self) -> "PlanService":
        return self.v1.plans

    @property
    @deprecated(
        """
        StripeClient.prices is deprecated, use StripeClient.v1.prices instead.
          All functionality under it has been copied over to StripeClient.v1.prices.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def prices(self) -> "PriceService":
        return self.v1.prices

    @property
    @deprecated(
        """
        StripeClient.privacy is deprecated, use StripeClient.v1.privacy instead.
          All functionality under it has been copied over to StripeClient.v1.privacy.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def privacy(self) -> "PrivacyService":
        return self.v1.privacy

    @property
    @deprecated(
        """
        StripeClient.products is deprecated, use StripeClient.v1.products instead.
          All functionality under it has been copied over to StripeClient.v1.products.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def products(self) -> "ProductService":
        return self.v1.products

    @property
    @deprecated(
        """
        StripeClient.promotion_codes is deprecated, use StripeClient.v1.promotion_codes instead.
          All functionality under it has been copied over to StripeClient.v1.promotion_codes.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def promotion_codes(self) -> "PromotionCodeService":
        return self.v1.promotion_codes

    @property
    @deprecated(
        """
        StripeClient.quotes is deprecated, use StripeClient.v1.quotes instead.
          All functionality under it has been copied over to StripeClient.v1.quotes.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def quotes(self) -> "QuoteService":
        return self.v1.quotes

    @property
    @deprecated(
        """
        StripeClient.radar is deprecated, use StripeClient.v1.radar instead.
          All functionality under it has been copied over to StripeClient.v1.radar.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def radar(self) -> "RadarService":
        return self.v1.radar

    @property
    @deprecated(
        """
        StripeClient.refunds is deprecated, use StripeClient.v1.refunds instead.
          All functionality under it has been copied over to StripeClient.v1.refunds.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def refunds(self) -> "RefundService":
        return self.v1.refunds

    @property
    @deprecated(
        """
        StripeClient.reporting is deprecated, use StripeClient.v1.reporting instead.
          All functionality under it has been copied over to StripeClient.v1.reporting.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def reporting(self) -> "ReportingService":
        return self.v1.reporting

    @property
    @deprecated(
        """
        StripeClient.reviews is deprecated, use StripeClient.v1.reviews instead.
          All functionality under it has been copied over to StripeClient.v1.reviews.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def reviews(self) -> "ReviewService":
        return self.v1.reviews

    @property
    @deprecated(
        """
        StripeClient.setup_attempts is deprecated, use StripeClient.v1.setup_attempts instead.
          All functionality under it has been copied over to StripeClient.v1.setup_attempts.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def setup_attempts(self) -> "SetupAttemptService":
        return self.v1.setup_attempts

    @property
    @deprecated(
        """
        StripeClient.setup_intents is deprecated, use StripeClient.v1.setup_intents instead.
          All functionality under it has been copied over to StripeClient.v1.setup_intents.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def setup_intents(self) -> "SetupIntentService":
        return self.v1.setup_intents

    @property
    @deprecated(
        """
        StripeClient.shipping_rates is deprecated, use StripeClient.v1.shipping_rates instead.
          All functionality under it has been copied over to StripeClient.v1.shipping_rates.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def shipping_rates(self) -> "ShippingRateService":
        return self.v1.shipping_rates

    @property
    @deprecated(
        """
        StripeClient.sigma is deprecated, use StripeClient.v1.sigma instead.
          All functionality under it has been copied over to StripeClient.v1.sigma.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def sigma(self) -> "SigmaService":
        return self.v1.sigma

    @property
    @deprecated(
        """
        StripeClient.sources is deprecated, use StripeClient.v1.sources instead.
          All functionality under it has been copied over to StripeClient.v1.sources.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def sources(self) -> "SourceService":
        return self.v1.sources

    @property
    @deprecated(
        """
        StripeClient.subscriptions is deprecated, use StripeClient.v1.subscriptions instead.
          All functionality under it has been copied over to StripeClient.v1.subscriptions.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def subscriptions(self) -> "SubscriptionService":
        return self.v1.subscriptions

    @property
    @deprecated(
        """
        StripeClient.subscription_items is deprecated, use StripeClient.v1.subscription_items instead.
          All functionality under it has been copied over to StripeClient.v1.subscription_items.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def subscription_items(self) -> "SubscriptionItemService":
        return self.v1.subscription_items

    @property
    @deprecated(
        """
        StripeClient.subscription_schedules is deprecated, use StripeClient.v1.subscription_schedules instead.
          All functionality under it has been copied over to StripeClient.v1.subscription_schedules.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def subscription_schedules(self) -> "SubscriptionScheduleService":
        return self.v1.subscription_schedules

    @property
    @deprecated(
        """
        StripeClient.tax is deprecated, use StripeClient.v1.tax instead.
          All functionality under it has been copied over to StripeClient.v1.tax.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def tax(self) -> "TaxService":
        return self.v1.tax

    @property
    @deprecated(
        """
        StripeClient.tax_codes is deprecated, use StripeClient.v1.tax_codes instead.
          All functionality under it has been copied over to StripeClient.v1.tax_codes.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def tax_codes(self) -> "TaxCodeService":
        return self.v1.tax_codes

    @property
    @deprecated(
        """
        StripeClient.tax_ids is deprecated, use StripeClient.v1.tax_ids instead.
          All functionality under it has been copied over to StripeClient.v1.tax_ids.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def tax_ids(self) -> "TaxIdService":
        return self.v1.tax_ids

    @property
    @deprecated(
        """
        StripeClient.tax_rates is deprecated, use StripeClient.v1.tax_rates instead.
          All functionality under it has been copied over to StripeClient.v1.tax_rates.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def tax_rates(self) -> "TaxRateService":
        return self.v1.tax_rates

    @property
    @deprecated(
        """
        StripeClient.terminal is deprecated, use StripeClient.v1.terminal instead.
          All functionality under it has been copied over to StripeClient.v1.terminal.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def terminal(self) -> "TerminalService":
        return self.v1.terminal

    @property
    @deprecated(
        """
        StripeClient.test_helpers is deprecated, use StripeClient.v1.test_helpers instead.
          All functionality under it has been copied over to StripeClient.v1.test_helpers.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def test_helpers(self) -> "TestHelpersService":
        return self.v1.test_helpers

    @property
    @deprecated(
        """
        StripeClient.tokens is deprecated, use StripeClient.v1.tokens instead.
          All functionality under it has been copied over to StripeClient.v1.tokens.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def tokens(self) -> "TokenService":
        return self.v1.tokens

    @property
    @deprecated(
        """
        StripeClient.topups is deprecated, use StripeClient.v1.topups instead.
          All functionality under it has been copied over to StripeClient.v1.topups.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def topups(self) -> "TopupService":
        return self.v1.topups

    @property
    @deprecated(
        """
        StripeClient.transfers is deprecated, use StripeClient.v1.transfers instead.
          All functionality under it has been copied over to StripeClient.v1.transfers.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def transfers(self) -> "TransferService":
        return self.v1.transfers

    @property
    @deprecated(
        """
        StripeClient.treasury is deprecated, use StripeClient.v1.treasury instead.
          All functionality under it has been copied over to StripeClient.v1.treasury.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def treasury(self) -> "TreasuryService":
        return self.v1.treasury

    @property
    @deprecated(
        """
        StripeClient.webhook_endpoints is deprecated, use StripeClient.v1.webhook_endpoints instead.
          All functionality under it has been copied over to StripeClient.v1.webhook_endpoints.
          See [migration guide](https://github.com/stripe/stripe-python/wiki/v1-namespace-in-StripeClient) for more on this and tips on migrating to the new v1 namespace.
        """,
    )
    def webhook_endpoints(self) -> "WebhookEndpointService":
        return self.v1.webhook_endpoints

    # deprecated v1 services: The end of the section generated from our OpenAPI spec
